
//-----------------------------LICENSE NOTICE------------------------------------
//
////////////////////////////////////////////////////////////////////////////////
///////////////////////////  SHOOT AND RUN /////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
//
//  Code & Graphics Copyright (C) 2020 Rafa Gutierrez (rafagutierrez@qq.com)
//
//  This file is part of Shoot and run: an Amstrad CPC Game made with CPCTelera
//  for CPCRetroDev 2020
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.


#include <cpctelera.h>
#include <man/game.h>
#include <man/animations.h>
#include <sprites/mothership.h>
#include <sprites/cloud.h>
#include <sprites/mothership_light.h>
#include <sprites/cloud_light.h>
#include <sprites/new_player.h>
#include <sprites/enemies_human.h>
#include <sprites/enemies_alien.h>
#include <sprites/minions_human.h>
#include <sprites/minions_alien.h>
#include <sprites/star_bot.h>
#include <sprites/chicken_bot.h>
#include <sprites/lives_human.h>
#include <sprites/lives_alien.h>
#include <sprites/ugly_alien.h>


/*                                                                      SPACE        Q             vx > 0        vx < 0          
                                            // level_end player_killed   shot        up            right          left              
    man_anim_player_waiting,                //      0          0          0           0             0               0   00000000               
    man_anim_player_walking_left,           //      0          0          0           0             0               1   00000001            
    man_anim_player_walking_right,          //      0          0          0           0             1               0   00000010        
    man_anim_player_waiting,                //      0          0          0           0             1               1   00000011 (not valid, ignore)
    man_anim_player_jumping_up,             //      0          0          0           1             0               0   00000100             
    man_anim_player_jumping_left,           //      0          0          0           1             0               1   00000101            
    man_anim_player_jumping_right,          //      0          0          0           1             1               0   00000110
    man_anim_player_waiting,                //      0          0          0           1             1               1   00000111 (not valid, ignore)
    man_anim_player_waiting,                //      0          0          1           0             0               0   00001000 (not valid, ignore)
    man_anim_player_aiming_left,            //      0          0          1           0             0               1   00001001            
    man_anim_player_aiming_right,           //      0          0          1           0             1               0   00001010
    man_anim_player_aiming_left_right,      //      0          0          1           0             1               1   00001011
    man_anim_player_aiming_up,              //      0          0          1           1             0               0   00001100                
    man_anim_player_aiming_up_left,         //      0          0          1           1             0               1   00001101            
    man_anim_player_aiming_up_right,        //      0          0          1           1             1               0   00001110
    man_anim_player_waiting,                //      0          0          1           1             1               1   00001111 (not valid, ignore)
-----------------------------------------------------------------------------------------------------------------------------------------------
    man_anim_player_death,                  //      0          1          0           0             0               0   00010000            
    man_anim_player_dancing                 //      1          0          0           0             0               0   00100000            
*/

AnimFrame_t const * const man_anim_player_array[] = {
    man_anim_player_waiting,         
    man_anim_player_walking_left,     
    man_anim_player_walking_right,    
    man_anim_player_waiting,         
    man_anim_player_jumping_up,       
    man_anim_player_jumping_left,     
    man_anim_player_jumping_right,    
    man_anim_player_waiting,         
    man_anim_player_waiting,         
    man_anim_player_aiming_left,      
    man_anim_player_aiming_right,     
    man_anim_player_aiming_left_right,
    man_anim_player_aiming_up,        
    man_anim_player_aiming_up_left,   
    man_anim_player_aiming_up_right,  
    man_anim_player_waiting         
};


AnimFrame_t const * const man_anim_alien_array[] = {
    man_anim_alien_waiting,         
    man_anim_alien_walking_left,     
    man_anim_alien_walking_right,    
    man_anim_alien_waiting,         
    man_anim_alien_jumping_up,       
    man_anim_alien_jumping_left,     
    man_anim_alien_jumping_right,    
    man_anim_alien_waiting,         
    man_anim_alien_waiting,         
    man_anim_alien_aiming_left,      
    man_anim_alien_aiming_right,     
    man_anim_alien_aiming_left_right,
    man_anim_alien_aiming_up,        
    man_anim_alien_aiming_up_left,   
    man_anim_alien_aiming_up_right,  
    man_anim_alien_waiting         
};



////////////////////////////////////////////////////////////////////////////////
// GET ANIMATION 
//      Returns the right animation given a status
//
// Inputs:
//      status: Animation status
// Output:
//      Pointer to the new animation
//
AnimFrame_t const * man_animations_getAnim(u8 new_status) {

    if (m_player_avatar == HUMAN)
        return ((AnimFrame_t const *)man_anim_player_array[new_status]);
    else
        return ((AnimFrame_t const *)man_anim_alien_array[new_status]);
    
}

/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////// PLAYER ANIMATIONS //////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//------------------------------------------------------------------------------
// Player: Standing
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_standing[] = {                                   // In CPC a frame last 1/50 seconds
        { man_anim_player_time2, { .sprite = spr_player_00    } }                  // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_standing } }          // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Player: Standing
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_waiting[] = {                                    // In CPC a frame last 1/50 seconds
        { man_anim_player_time2, { .sprite = spr_player_00    } }                  // {.sprite = X} means union sprite field = X
    ,   { man_anim_player_time1, { .sprite = spr_player_01    } }                  // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_waiting } }           // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Player: Walking left
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_walking_left[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_player_time3, { .sprite = spr_player_10    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_player_time3, { .sprite = spr_player_11    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_walking_left } }       // {.next   = X} means union next field = X
};    


//------------------------------------------------------------------------------
// Player: Walking right
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_walking_right[] = {                               // In CPC a frame last 1/50 seconds
        { man_anim_player_time3, { .sprite = spr_player_13    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_player_time3, { .sprite = spr_player_14    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_walking_right } }      // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Player: Jumping up
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_jumping_up[] = {                                  // In CPC a frame last 1/50 seconds
        { man_anim_player_time3, { .sprite = spr_player_02    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_player_time3, { .sprite = spr_player_03    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_player_time3, { .sprite = spr_player_02    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_player_time3, { .sprite = spr_player_00    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_jumping_up } }         // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Player: Jumping left
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_jumping_left[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_player_time3, { .sprite = spr_player_04    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_player_time3, { .sprite = spr_player_05    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_player_time3, { .sprite = spr_player_04    } }                   // {.sprite = X} means union sprite field = X    
    ,   { man_anim_player_time3, { .sprite = spr_player_00    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_jumping_left } }       // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Player: Jumping right
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_jumping_right[] = {                               // In CPC a frame last 1/50 seconds
        { man_anim_player_time3, { .sprite = spr_player_06    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_player_time3, { .sprite = spr_player_07    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_player_time3, { .sprite = spr_player_06    } }                   // {.sprite = X} means union sprite field = X    
    ,   { man_anim_player_time3, { .sprite = spr_player_00    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_jumping_right } }      // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Player: Aiming up
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_aiming_up[] = {                                   // In CPC a frame last 1/50 seconds
        { man_anim_player_time3, { .sprite = spr_player_08    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_aiming_up } }          // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Player: Aiming left
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_aiming_left[] = {                                 // In CPC a frame last 1/50 seconds
        { man_anim_player_time3, { .sprite = spr_player_10    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_aiming_left } }        // {.next   = X} means union next field = X
};

//------------------------------------------------------------------------------
// Player: Aiming right
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_aiming_right[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_player_time3, { .sprite = spr_player_13    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_aiming_right } }       // {.next   = X} means union next field = X
};

//------------------------------------------------------------------------------
// Player: Aiming up and left
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_aiming_up_left[] = {                              // In CPC a frame last 1/50 seconds
        { man_anim_player_time3, { .sprite = spr_player_12    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_aiming_up_left } }     // {.next   = X} means union next field = X
};

//------------------------------------------------------------------------------
// Player: Aiming up and right
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_aiming_up_right[] = {                             // In CPC a frame last 1/50 seconds
        { man_anim_player_time3, { .sprite = spr_player_15    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_aiming_up_right } }    // {.next   = X} means union next field = X
};

//------------------------------------------------------------------------------
// Player: Aiming left and right
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_aiming_left_right[] = {                           // In CPC a frame last 1/50 seconds
        { man_anim_player_time3, { .sprite = spr_player_09    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_aiming_left_right } }  // {.next   = X} means union next field = X
};

//------------------------------------------------------------------------------
// Player: Death
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_death[] = {                                       // In CPC a frame last 1/50 seconds
        { man_anim_player_time3, { .sprite = spr_player_16    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_player_time3, { .sprite = spr_player_17    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_player_time3, { .sprite = spr_player_18    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_player_time3, { .sprite = spr_player_19    } }                   // {.sprite = X} means union sprite field = X
    ,   { 100                  , { .sprite = spr_player_20    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_death } }              // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Player: Dancing
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_dancing[] = {                                     // In CPC a frame last 1/50 seconds
        { man_anim_player_time3, { .sprite = spr_player_21    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_player_time3, { .sprite = spr_player_22    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_player_time3, { .sprite = spr_player_21    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_player_time3, { .sprite = spr_player_23    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_dancing } }            // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Player: Show off
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_show_off[] = {                                     // In CPC a frame last 1/50 seconds
        { 10, { .sprite = spr_player_00    } }                   // {.sprite = X} means union sprite field = X
    ,   { 10, { .sprite = spr_player_10    } }                   // {.sprite = X} means union sprite field = X
    ,   { 10, { .sprite = spr_player_13    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_player_10    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_player_12    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_player_09    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_player_15    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_player_13    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_player_15    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_player_09    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_player_12    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_player_10    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_show_off } }            // {.next   = X} means union next field = X
};    


//------------------------------------------------------------------------------
// Player: Sit
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_player_sit[] = {                                     // In CPC a frame last 1/50 seconds
        { 100, { .sprite = spr_lives_human_0    } }                                   // {.sprite = X} means union sprite field = X
    ,   { 10, { .sprite  = spr_lives_human_1    } }                                    // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_player_sit } }            // {.next   = X} means union next field = X
};    



/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////





/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////// ALIEN ANIMATIONS //////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//------------------------------------------------------------------------------
// Alien: Standing
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_standing[] = {                                   // In CPC a frame last 1/50 seconds
        { man_anim_alien_time2, { .sprite = spr_alien_00    } }                  // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_alien_standing } }          // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien: Standing
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_waiting[] = {                                    // In CPC a frame last 1/50 seconds
        { man_anim_alien_time2, { .sprite = spr_alien_00    } }                  // {.sprite = X} means union sprite field = X
    ,   { man_anim_alien_time1, { .sprite = spr_alien_01    } }                  // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_alien_waiting } }           // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien: Walking left
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_walking_left[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_alien_time3, { .sprite = spr_alien_10    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_alien_time3, { .sprite = spr_alien_11    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_alien_walking_left } }       // {.next   = X} means union next field = X
};    


//------------------------------------------------------------------------------
// Alien: Walking right
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_walking_right[] = {                               // In CPC a frame last 1/50 seconds
        { man_anim_alien_time3, { .sprite = spr_alien_13    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_alien_time3, { .sprite = spr_alien_14    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_alien_walking_right } }      // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien: Jumping up
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_jumping_up[] = {                                  // In CPC a frame last 1/50 seconds
        { man_anim_alien_time3, { .sprite = spr_alien_02    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_alien_time3, { .sprite = spr_alien_03    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_alien_time3, { .sprite = spr_alien_02    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_alien_time3, { .sprite = spr_alien_00    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_alien_jumping_up } }         // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien: Jumping left
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_jumping_left[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_alien_time3, { .sprite = spr_alien_04    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_alien_time3, { .sprite = spr_alien_05    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_alien_time3, { .sprite = spr_alien_04    } }                   // {.sprite = X} means union sprite field = X    
    ,   { man_anim_alien_time3, { .sprite = spr_alien_00    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_alien_jumping_left } }       // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien: Jumping right
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_jumping_right[] = {                               // In CPC a frame last 1/50 seconds
        { man_anim_alien_time3, { .sprite = spr_alien_06    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_alien_time3, { .sprite = spr_alien_07    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_alien_time3, { .sprite = spr_alien_06    } }                   // {.sprite = X} means union sprite field = X    
    ,   { man_anim_alien_time3, { .sprite = spr_alien_00    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_alien_jumping_right } }      // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien: Aiming up
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_aiming_up[] = {                                   // In CPC a frame last 1/50 seconds
        { man_anim_alien_time3, { .sprite = spr_alien_08    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_alien_aiming_up } }          // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien: Aiming left
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_aiming_left[] = {                                 // In CPC a frame last 1/50 seconds
        { man_anim_alien_time3, { .sprite = spr_alien_10    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_alien_aiming_left } }        // {.next   = X} means union next field = X
};

//------------------------------------------------------------------------------
// Alien: Aiming right
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_aiming_right[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_alien_time3, { .sprite = spr_alien_13    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_alien_aiming_right } }       // {.next   = X} means union next field = X
};

//------------------------------------------------------------------------------
// Alien: Aiming up and left
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_aiming_up_left[] = {                              // In CPC a frame last 1/50 seconds
        { man_anim_alien_time3, { .sprite = spr_alien_12    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_alien_aiming_up_left } }     // {.next   = X} means union next field = X
};

//------------------------------------------------------------------------------
// Alien: Aiming up and right
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_aiming_up_right[] = {                             // In CPC a frame last 1/50 seconds
        { man_anim_alien_time3, { .sprite = spr_alien_15    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_alien_aiming_up_right } }    // {.next   = X} means union next field = X
};

//------------------------------------------------------------------------------
// Alien: Aiming left and right
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_aiming_left_right[] = {                           // In CPC a frame last 1/50 seconds
        { man_anim_alien_time3, { .sprite = spr_alien_09    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_alien_aiming_left_right } }  // {.next   = X} means union next field = X
};

//------------------------------------------------------------------------------
// Alien: Death
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_death[] = {                                      // In CPC a frame last 1/50 seconds
        { man_anim_alien_time3, { .sprite = spr_alien_16    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_alien_time3, { .sprite = spr_alien_17    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_alien_time3, { .sprite = spr_alien_18    } }                   // {.sprite = X} means union sprite field = X
    ,   { 100,                  { .sprite = spr_alien_19    } }                   // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_death } }              // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien: Dancing
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_dancing[] = {                                     // In CPC a frame last 1/50 seconds
        { man_anim_alien_time3, { .sprite = spr_alien_20    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_alien_time3, { .sprite = spr_alien_21    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_alien_time3, { .sprite = spr_alien_22    } }                   // {.sprite = X} means union sprite field = X
    ,   { man_anim_alien_time3, { .sprite = spr_alien_23    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_alien_dancing } }            // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien: Show off
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_show_off[] = {                                     // In CPC a frame last 1/50 seconds
        { 10, { .sprite = spr_alien_00    } }                   // {.sprite = X} means union sprite field = X
    ,   { 10, { .sprite = spr_alien_10    } }                   // {.sprite = X} means union sprite field = X
    ,   { 10, { .sprite = spr_alien_13    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_alien_10    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_alien_12    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_alien_09    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_alien_15    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_alien_13    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_alien_15    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_alien_09    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_alien_12    } }                   // {.sprite = X} means union sprite field = X
    ,   { 5, { .sprite = spr_alien_10    } }                   // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_alien_show_off } }            // {.next   = X} means union next field = X
};    


//------------------------------------------------------------------------------
// Alien: Sit
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_sit[] = {                                     // In CPC a frame last 1/50 seconds
        { 100, { .sprite = spr_lives_alien_0    } }                                   // {.sprite = X} means union sprite field = X
    ,   { 10, { .sprite =  spr_lives_alien_1    } }                                    // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_alien_sit } }            // {.next   = X} means union next field = X
};    



/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////




//------------------------------------------------------------------------------
// Mothership: Normal movement animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_mothership[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_mothership_time, { .sprite = spr_mothership_0    } }   // {.sprite = X} means union sprite field = X
    ,   { man_anim_mothership_time, { .sprite = spr_mothership_1    } }   // {.sprite = X} means union sprite field = X
    ,   {                         0, { .next   = man_anim_mothership } }   // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Cloud: Normal movement animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_cloud[] = {                                  // In CPC a frame last 1/50 seconds
        { man_anim_cloud_time, { .sprite = spr_cloud_0    } }           // {.sprite = X} means union sprite field = X
    ,   { man_anim_cloud_time, { .sprite = spr_cloud_1    } }           // {.sprite = X} means union sprite field = X
    ,   {                         0, { .next   = man_anim_cloud } }     // {.next   = X} means union next field = X
};    


//------------------------------------------------------------------------------
// Mothership light
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_mothership_light[] = {                                    // In CPC a frame last 1/50 seconds
        { man_anim_mothership_light_time, { .sprite = spr_mothership_light_0    } }  // {.sprite = X} means union sprite field = X
    ,   { man_anim_mothership_light_time, { .sprite = spr_mothership_light_1    } }  // {.sprite = X} means union sprite field = X
    ,   {                         0, { .next   = man_anim_mothership_light } }       // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Cloud light
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_cloud_light[] = {                                    // In CPC a frame last 1/50 seconds
        { man_anim_mothership_light_time, { .sprite = spr_cloud_light_0    } }  // {.sprite = X} means union sprite field = X
    ,   { man_anim_mothership_light_time, { .sprite = spr_cloud_light_1    } }  // {.sprite = X} means union sprite field = X
    ,   {                         0, { .next   = man_anim_cloud_light } }        // {.next   = X} means union next field = X
};    


//------------------------------------------------------------------------------
// Enemy bot: Star animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_starbot[] = {                                       // In CPC a frame last 1/50 seconds
        { man_anim_starbot_time, { .sprite = spr_star_bot_2    } }             // {.sprite = X} means union sprite field = X
    ,   { man_anim_starbot_time, { .sprite = spr_star_bot_3    } }             // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_starbot } }              // {.next   = X} means union next field = X
};  


//------------------------------------------------------------------------------
// Chicken bot: Star animation
//------------------------------------------------------------------------------

const AnimFrame_t man_anim_chickenbot[] = {                                       // In CPC a frame last 1/50 seconds
        { man_anim_chickenbot_time, { .sprite = spr_chicken_bot_2    } }             // {.sprite = X} means union sprite field = X
    ,   { man_anim_chickenbot_time, { .sprite = spr_chicken_bot_3    } }             // {.sprite = X} means union sprite field = X
    ,   {                     0, { .next   = man_anim_chickenbot } }              // {.next   = X} means union next field = X
};  



/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////// ALIEN ENEMIES ANIMATIONS ///////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
  
//------------------------------------------------------------------------------
// Alien enemy 1: Normal movement animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_enemy1[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_enemy_time, { .sprite = spr_enemies_alien_00    } }         // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_time, { .sprite = spr_enemies_alien_01    } }         // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_enemy1 } }        // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien enemy 1: Killing animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_enemy1_death[] = {                          // In CPC a frame last 1/50 seconds
        { man_anim_enemy_death_time, { .sprite = spr_enemies_alien_02    } }   // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_death_time, { .sprite = spr_enemies_alien_03    } }   // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_enemy1_death } }  // {.next   = X} means union next field = X
};   

//------------------------------------------------------------------------------
// Alien enemy 2: Normal movement animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_enemy2[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_enemy_time, { .sprite = spr_enemies_alien_04    } }         // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_time, { .sprite = spr_enemies_alien_05    } }         // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_enemy2 } }        // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien enemy 2: Killing animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_enemy2_death[] = {                          // In CPC a frame last 1/50 seconds
        { man_anim_enemy_death_time, { .sprite = spr_enemies_alien_06    } }   // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_death_time, { .sprite = spr_enemies_alien_07    } }   // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_enemy2_death } }  // {.next   = X} means union next field = X
}; 


//------------------------------------------------------------------------------
// Alien enemy 3: Normal movement animation 
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_enemy3[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_enemy_time, { .sprite = spr_enemies_alien_08    } }         // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_time, { .sprite = spr_enemies_alien_09    } }         // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_enemy3 } }        // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien enemy 3: Killing animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_enemy3_death[] = {                           // In CPC a frame last 1/50 seconds
        { man_anim_enemy_death_time, { .sprite = spr_enemies_alien_10    } }    // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_death_time, { .sprite = spr_enemies_alien_11    } }    // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_enemy3_death } }   // {.next   = X} means union next field = X
};    


//------------------------------------------------------------------------------
// Alien enemy 4: Normal movement animation 
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_enemy4[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_enemy_time, { .sprite = spr_enemies_alien_12    } }         // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_time, { .sprite = spr_enemies_alien_13    } }         // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_enemy4 } }        // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien enemy 4: Killing animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_enemy4_death[] = {                           // In CPC a frame last 1/50 seconds
        { man_anim_enemy_death_time, { .sprite = spr_enemies_alien_14    } }    // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_death_time, { .sprite = spr_enemies_alien_15    } }    // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_enemy4_death } }   // {.next   = X} means union next field = X
};  



//------------------------------------------------------------------------------
// Alien Minion 1: Normal movement animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_minion1[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_enemy_time, { .sprite = spr_minions_alien_00    } }         // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_time, { .sprite = spr_minions_alien_01    } }         // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_minion1 } }        // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien Minion 1: Killing animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_minion1_death[] = {                          // In CPC a frame last 1/50 seconds
        { man_anim_enemy_death_time, { .sprite = spr_minions_alien_02    } }   // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_death_time, { .sprite = spr_minions_alien_03    } }   // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_minion1_death } }  // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien Minion 2: Normal movement animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_minion2[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_enemy_time, { .sprite = spr_minions_alien_04    } }        // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_time, { .sprite = spr_minions_alien_05    } }        // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_minion2 } }        // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien Minion 2: Killing animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_minion2_death[] = {                          // In CPC a frame last 1/50 seconds
        { man_anim_enemy_death_time, { .sprite = spr_minions_alien_06    } }   // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_death_time, { .sprite = spr_minions_alien_07    } }   // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_minion2_death } }  // {.next   = X} means union next field = X
};  


//------------------------------------------------------------------------------
// Alien Minion 3: Normal movement animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_minion3[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_enemy_time, { .sprite = spr_minions_alien_08    } }        // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_time, { .sprite = spr_minions_alien_09    } }        // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_minion3 } }        // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien Minion 3: Killing animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_minion3_death[] = {                          // In CPC a frame last 1/50 seconds
        { man_anim_enemy_death_time, { .sprite = spr_minions_alien_10    } }   // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_death_time, { .sprite = spr_minions_alien_11    } }   // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_minion3_death } }  // {.next   = X} means union next field = X
};  


//------------------------------------------------------------------------------
// Alien Minion 4: Normal movement animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_minion4[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_enemy_time, { .sprite = spr_minions_alien_12    } }        // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_time, { .sprite = spr_minions_alien_13    } }        // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_minion4 } }        // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Alien Minion 4: Killing animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_alien_minion4_death[] = {                          // In CPC a frame last 1/50 seconds
        { man_anim_enemy_death_time, { .sprite = spr_minions_alien_14    } }   // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_death_time, { .sprite = spr_minions_alien_15    } }   // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_alien_minion4_death } }  // {.next   = X} means union next field = X
};  



/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////// HUMAN ENEMIES ANIMATIONS ///////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
  
//------------------------------------------------------------------------------
// Human enemy 1: Normal movement animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_human_enemy1[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_enemy_time, { .sprite = spr_enemies_human_00    } }         // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_time, { .sprite = spr_enemies_human_01    } }         // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_human_enemy1 } }        // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Human enemy 1: Killing animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_human_enemy1_death[] = {                          // In CPC a frame last 1/50 seconds
        { man_anim_enemy_death_time, { .sprite = spr_enemies_human_02    } }   // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_death_time, { .sprite = spr_enemies_human_03    } }   // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_human_enemy1_death } }  // {.next   = X} means union next field = X
};   

//------------------------------------------------------------------------------
// Human enemy 2: Normal movement animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_human_enemy2[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_enemy_time, { .sprite = spr_enemies_human_04    } }         // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_time, { .sprite = spr_enemies_human_05    } }         // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_human_enemy2 } }        // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Human enemy 2: Killing animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_human_enemy2_death[] = {                          // In CPC a frame last 1/50 seconds
        { man_anim_enemy_death_time, { .sprite = spr_enemies_human_06    } }   // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_death_time, { .sprite = spr_enemies_human_07    } }   // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_human_enemy2_death } }  // {.next   = X} means union next field = X
}; 


//------------------------------------------------------------------------------
// Human enemy 3: Normal movement animation 
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_human_enemy3[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_enemy_time, { .sprite = spr_enemies_human_08    } }         // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_time, { .sprite = spr_enemies_human_09    } }         // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_human_enemy3 } }        // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Human enemy 3: Killing animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_human_enemy3_death[] = {                           // In CPC a frame last 1/50 seconds
        { man_anim_enemy_death_time, { .sprite = spr_enemies_human_10    } }    // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_death_time, { .sprite = spr_enemies_human_11    } }    // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_human_enemy3_death } }   // {.next   = X} means union next field = X
};    


//------------------------------------------------------------------------------
// Human enemy 4: Normal movement animation 
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_human_enemy4[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_enemy_time, { .sprite = spr_enemies_human_12    } }         // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_time, { .sprite = spr_enemies_human_13    } }         // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_human_enemy4 } }        // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Human enemy 4: Killing animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_human_enemy4_death[] = {                           // In CPC a frame last 1/50 seconds
        { man_anim_enemy_death_time, { .sprite = spr_enemies_human_14    } }    // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_death_time, { .sprite = spr_enemies_human_15    } }    // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_human_enemy4_death } }   // {.next   = X} means union next field = X
};  



//------------------------------------------------------------------------------
// Human Minion 1: Normal movement animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_human_minion1[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_enemy_time, { .sprite = spr_minions_human_00    } }         // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_time, { .sprite = spr_minions_human_01    } }         // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_human_minion1 } }        // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Human Minion 1: Killing animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_human_minion1_death[] = {                          // In CPC a frame last 1/50 seconds
        { man_anim_enemy_death_time, { .sprite = spr_minions_human_02    } }   // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_death_time, { .sprite = spr_minions_human_03    } }   // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_human_minion1_death } }  // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Human Minion 2: Normal movement animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_human_minion2[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_enemy_time, { .sprite = spr_minions_human_04    } }        // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_time, { .sprite = spr_minions_human_05    } }        // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_human_minion2 } }        // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Human Minion 2: Killing animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_human_minion2_death[] = {                          // In CPC a frame last 1/50 seconds
        { man_anim_enemy_death_time, { .sprite = spr_minions_human_06    } }   // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_death_time, { .sprite = spr_minions_human_07    } }   // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_human_minion2_death } }  // {.next   = X} means union next field = X
};  


//------------------------------------------------------------------------------
// Human Minion 3: Normal movement animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_human_minion3[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_enemy_time, { .sprite = spr_minions_human_08    } }        // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_time, { .sprite = spr_minions_human_09    } }        // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_human_minion3 } }        // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Human Minion 3: Killing animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_human_minion3_death[] = {                          // In CPC a frame last 1/50 seconds
        { man_anim_enemy_death_time, { .sprite = spr_minions_human_10    } }   // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_death_time, { .sprite = spr_minions_human_11    } }   // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_human_minion3_death } }  // {.next   = X} means union next field = X
};  


//------------------------------------------------------------------------------
// Human Minion 4: Normal movement animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_human_minion4[] = {                                // In CPC a frame last 1/50 seconds
        { man_anim_enemy_time, { .sprite = spr_minions_human_12    } }        // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_time, { .sprite = spr_minions_human_13    } }        // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_human_minion4 } }        // {.next   = X} means union next field = X
};    

//------------------------------------------------------------------------------
// Human Minion 4: Killing animation
//------------------------------------------------------------------------------
const AnimFrame_t man_anim_human_minion4_death[] = {                          // In CPC a frame last 1/50 seconds
        { man_anim_enemy_death_time, { .sprite = spr_minions_human_14    } }   // {.sprite = X} means union sprite field = X
    ,   { man_anim_enemy_death_time, { .sprite = spr_minions_human_15    } }   // {.sprite = X} means union sprite field = X
    ,   {                    0, { .next   = man_anim_human_minion4_death } }  // {.next   = X} means union next field = X
};  




