//-----------------------------LICENSE NOTICE------------------------------------
//
////////////////////////////////////////////////////////////////////////////////
///////////////////////////  SHOOT AND RUN /////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
//
//  Code & Graphics Copyright (C) 2020 Rafa Gutierrez (rafagutierrez@qq.com)
//
//  This file is part of Shoot and run: an Amstrad CPC Game made with CPCTelera
//  for CPCRetroDev 2020
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.


#pragma once                    // to avoid including several times
#include <cpctelera.h>
//#include <man/entity.h>

//==============================================================================
// PUBLIC CONSTANTS
//==============================================================================
//
//------------------------------------------------------------------------------
// Animations
#define man_anim_enemy_time             10
#define man_anim_starbot_time           2
#define man_anim_chickenbot_time        1
#define man_anim_enemy_death_time       3
#define man_anim_player_death_time      3
#define man_anim_mothership_time        5
#define man_anim_mothership_light_time  1
#define man_anim_cloud_time             5
#define man_anim_player_time1           8 
#define man_anim_player_time2           45
#define man_anim_player_time3           3
#define man_anim_alien_time1            8 
#define man_anim_alien_time2            45
#define man_anim_alien_time3            3


//==============================================================================
// PUBLIC DATA STRUCTURES
//==============================================================================

//------------------------------------------------------------------------------
// Forward declarations of structures and type definitions
// Animation Structure
typedef struct AnimFrame_t AnimFrame_t;                   // Animation Frame
typedef union  SpriteOrNextFrame_t SpriteOrNextFrame_t;   // Frame or animation restart

//------------------------------------------------------------------------------
// Structures for animations
// Note: const is an attribute for whatever it has at its LEFT side
// x is not a pointer (west const = east const)
// u8 const x       same as     const u8  x   // x value cannot be changed
//
// x is a pointer to u8 (x is an address that points to an u8 value)
// u8 const * x     same as     const u8 * x  // the u8 value pointed by x cannot be changed                                            
// u8 * const x                               // the address that points to the u8 value cannot be changed
// u8 const * const x                         // neither the address or the pointed value can be changed
// Tip: It's easier to read if we use const on the RIGHT of the variable that we want to be a constant

// A pointer inside an animation frame represents either...
// 1) a sprite, or 2) a pointer to restart the animation
union SpriteOrNextFrame_t {
    // pointers cannot be modified (always point to the same place)
    u8 const * const            sprite;        // Sprite pointer cannot be modified 
    AnimFrame_t const * const   next;          // Pointer to restart animation (next AnimFrame)
};

// A frame of animation has a time and a sprite (val.sprite)
// When time is 0, it signals the end of the animation
// At the end of animation, val contains a pointer to restart the animation
struct AnimFrame_t {
    // Sprite duration = time/50 seconds
    u8 const           time;                   // Number of cycles this frame will take
    SpriteOrNextFrame_t val;                   // Sprite for this frame 2 bytes
};

extern const AnimFrame_t man_anim_player_standing[];            // Num sprites: 1 Id: 00
extern const AnimFrame_t man_anim_player_waiting[];             // Num sprites: 2 Id: 00-01
extern const AnimFrame_t man_anim_player_walking_left[];        // Num sprites: 2 Id: 10-11
extern const AnimFrame_t man_anim_player_walking_right[];       // Num sprites: 2 Id: 13-14
extern const AnimFrame_t man_anim_player_jumping_up[];          // Num sprites: 3 Id: 02-03-02
extern const AnimFrame_t man_anim_player_jumping_left[];        // Num sprites: 3 Id: 04-05-04
extern const AnimFrame_t man_anim_player_jumping_right[];       // Num sprites: 3 Id: 06-07-06
extern const AnimFrame_t man_anim_player_aiming_up[];           // Num sprites: 1 Id: 08
extern const AnimFrame_t man_anim_player_aiming_left[];         // Num sprites: 1 Id: 10
extern const AnimFrame_t man_anim_player_aiming_right[];        // Num sprites: 1 Id: 13
extern const AnimFrame_t man_anim_player_aiming_up_left[];      // Num sprites: 1 Id: 12
extern const AnimFrame_t man_anim_player_aiming_up_right[];     // Num sprites: 1 Id: 15
extern const AnimFrame_t man_anim_player_aiming_left_right[];   // Num sprites: 1 Id: 09
extern const AnimFrame_t man_anim_player_death[];               // Num sprites: 5 Id: 16-17-18-19-20
extern const AnimFrame_t man_anim_player_dancing[];             // Num sprites: 4 Id: 21-22-21-23
extern const AnimFrame_t man_anim_player_show_off[];            //
extern const AnimFrame_t man_anim_player_sit[];                 // 

extern const AnimFrame_t man_anim_alien_standing[];            // Num sprites: 1 Id: 00
extern const AnimFrame_t man_anim_alien_waiting[];             // Num sprites: 2 Id: 00-01
extern const AnimFrame_t man_anim_alien_walking_left[];        // Num sprites: 2 Id: 10-11
extern const AnimFrame_t man_anim_alien_walking_right[];       // Num sprites: 2 Id: 13-14
extern const AnimFrame_t man_anim_alien_jumping_up[];          // Num sprites: 3 Id: 02-03-02
extern const AnimFrame_t man_anim_alien_jumping_left[];        // Num sprites: 3 Id: 04-05-04
extern const AnimFrame_t man_anim_alien_jumping_right[];       // Num sprites: 3 Id: 06-07-06
extern const AnimFrame_t man_anim_alien_aiming_up[];           // Num sprites: 1 Id: 08
extern const AnimFrame_t man_anim_alien_aiming_left[];         // Num sprites: 1 Id: 10
extern const AnimFrame_t man_anim_alien_aiming_right[];        // Num sprites: 1 Id: 13
extern const AnimFrame_t man_anim_alien_aiming_up_left[];      // Num sprites: 1 Id: 12
extern const AnimFrame_t man_anim_alien_aiming_up_right[];     // Num sprites: 1 Id: 15
extern const AnimFrame_t man_anim_alien_aiming_left_right[];   // Num sprites: 1 Id: 09
extern const AnimFrame_t man_anim_alien_death[];               // Num sprites: 5 Id: 16-17-18-19
extern const AnimFrame_t man_anim_alien_dancing[];             // Num sprites: 4 Id: 20-21-22-23
extern const AnimFrame_t man_anim_alien_show_off[];            //
extern const AnimFrame_t man_anim_alien_sit[];                 // 

extern const AnimFrame_t man_anim_mothership[];  
extern const AnimFrame_t man_anim_mothership_light[];
extern const AnimFrame_t man_anim_cloud_light[];  

extern const AnimFrame_t man_anim_cloud[];  
extern const AnimFrame_t man_anim_starbot[];   
extern const AnimFrame_t man_anim_chickenbot[];      

extern const AnimFrame_t man_anim_alien_enemy1[];       
extern const AnimFrame_t man_anim_alien_enemy2[];       
extern const AnimFrame_t man_anim_alien_enemy3[];       
extern const AnimFrame_t man_anim_alien_enemy4[];       
extern const AnimFrame_t man_anim_alien_enemy1_death[]; 
extern const AnimFrame_t man_anim_alien_enemy2_death[]; 
extern const AnimFrame_t man_anim_alien_enemy3_death[]; 
extern const AnimFrame_t man_anim_alien_enemy4_death[]; 
extern const AnimFrame_t man_anim_alien_minion1[];
extern const AnimFrame_t man_anim_alien_minion2[];
extern const AnimFrame_t man_anim_alien_minion3[];
extern const AnimFrame_t man_anim_alien_minion4[];
extern const AnimFrame_t man_anim_alien_minion1_death[];
extern const AnimFrame_t man_anim_alien_minion2_death[];
extern const AnimFrame_t man_anim_alien_minion3_death[];
extern const AnimFrame_t man_anim_alien_minion4_death[];

extern const AnimFrame_t man_anim_human_enemy1[];       
extern const AnimFrame_t man_anim_human_enemy2[];       
extern const AnimFrame_t man_anim_human_enemy3[];       
extern const AnimFrame_t man_anim_human_enemy4[];       
extern const AnimFrame_t man_anim_human_enemy1_death[]; 
extern const AnimFrame_t man_anim_human_enemy2_death[]; 
extern const AnimFrame_t man_anim_human_enemy3_death[]; 
extern const AnimFrame_t man_anim_human_enemy4_death[]; 
extern const AnimFrame_t man_anim_human_minion1[];
extern const AnimFrame_t man_anim_human_minion2[];
extern const AnimFrame_t man_anim_human_minion3[];
extern const AnimFrame_t man_anim_human_minion4[];
extern const AnimFrame_t man_anim_human_minion1_death[];
extern const AnimFrame_t man_anim_human_minion2_death[];
extern const AnimFrame_t man_anim_human_minion3_death[];
extern const AnimFrame_t man_anim_human_minion4_death[];








//==============================================================================
// PUBLIC INTERFACE
//==============================================================================
//extern AnimFrame_t const * man_animations_getAnim(u8 new_status);
extern AnimFrame_t const * man_animations_getAnim(u8 new_status);


//------------------------------------------------------------------------------
// Different options for the animation structure
//------------------------------------------------------------------------------
//
// OPTION 1: Array of sprite pointers
// u8* const man_anim_enemy1[3] = { spr_enemy1_0, spr_enemy1_1};    // const is an attribute of the pointer
//
// How do we know the end of the array? last array element is a null pointer to the end
// u8* const man_anim_enemy1[3] = { spr_enemy1_0, spr_enemy1_1, 0x0000};    // 0x0000 = pointer to NULL
//
// If we want to loop the animation? last array element is a pointer to the first frame of the animation
// 
// If the frames of the animation do not have the same duration?
//
// OPTION 2: Array of animation type (time + sprite pointers)
// struct AnimFrame_t {
//      u8  time;                               
//      u8*  sprite;
//  }
//
// const struct AnimFrame_t* const man_anim_enemy1[3] = {       // In CPC a frame last 1/50 seconds
//         { 12, spr_enemy1_0}                                  // sprite last 12/50 seconds
//     ,   { 12, spr_enemy1_1}                                  // sprite last 12/50 seconds
//     ,   {  0, 0x0000}
// };    
// In order to loop the animation array last element should be a pointer to the 1st element
// Problem: that pointer is a sprite pointer not an AnimeFrame_t pointer
//
// OPTION 3: Array of animation type (time + sprite pointers + next_pointer)
// struct AnimFrame_t {
//      u8  time;                               
//      u8*  sprite;
//      struct AnimeFrame_t* next;
//  }
//
// const struct AnimFrame_t man_anim_enemy1[3] = {              // In CPC a frame last 1/50 seconds
//         { 12, spr_enemy1_0, 0x0000}                          // sprite last 12/50 seconds
//     ,   { 12, spr_enemy1_1, 0x0000}                          // sprite last 12/50 seconds
//     ,   {  0, 0x0000, man_anim_enemy1}
// };    
//
// Problem: We waste 2 bytes per animation frame since we never use 
// AnimFrame_t.sprite pointer and AnimFrame_t.next pointer at the same time
//
// OPTION 4: Array of animation type (time + void pointers)
// struct AnimFrame_t {
//      u8  time;                               
//      void*  sprite;
//  }
//  If time > 0 then cast of void pointer to (u8*)
//  If time = 0 then cast of void pointer to (AnimFrame_t*)
//
// OPTION 5: 
// How to say compiler the struct AnimFrame_t has 2 pointers but in reality is only one pointer
// that some times points to u8 and some times points to AnimFrame_t? using UNION instead of STRUCT
//
// typedef struct AnFr_t AnimFrame_t;
// typedef union  SpFr_t SpriteOrNextFrame_t;
// 
// Union means the fields are different options that have to be store in the same memory space
// Union saves enough memory space to storage the biggest alternative
//
// union uni {          // union would save space to storage 11 bytes
//      u8  t;          // 1 byte
//          e;  // 11 bytes
// }
//
// In this case the union alternatives are two pointers that point to different types of data
// a pointer to a sprite or a pointer to AnimFrame_t all
// Union only needs memory space to storage 2 bytes to save ONLY ONE of the alternatives (a pointer)
//union SpFr_t {
//    u8*          sprite;
//    AnimFrame_t* next;
// };
//
// Struct needs memory space to storage ALL the fields
// struct AnFr_t {
//     u8                  time;                                // duration of the sprite time/50 seconds
//     SpriteOrNextFrame_t val;                                 // 2 bytes
// };
//  If time > 0 then val points to a sprite
//  If time = 0 then val points to first animation frame