//-----------------------------LICENSE NOTICE------------------------------------
//
////////////////////////////////////////////////////////////////////////////////
///////////////////////////  SHOOT AND RUN /////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
//
//  Code & Graphics Copyright (C) 2020 Rafa Gutierrez (rafagutierrez@qq.com)
//
//  This file is part of Shoot and run: an Amstrad CPC Game made with CPCTelera
//  for CPCRetroDev 2020
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.


#include "entity_templates.h"
#include "custom_sprites.h"
#include <sprites/mothership.h>
#include <sprites/cloud.h>
#include <sprites/mothership_light.h>
#include <sprites/cloud_light.h>
#include <sprites/new_player.h>
#include <sprites/ugly_alien.h>
#include <sprites/light.h>
#include <sprites/mothership_light.h>
#include <sprites/cloud_light.h>
#include <sprites/lives_human.h>
#include <sprites/lives_alien.h>
#include <sprites/enemies_human.h>
#include <sprites/enemies_alien.h>
#include <sprites/minions_human.h>
#include <sprites/minions_alien.h>
#include <sprites/vshot.h>
#include <sprites/eggs.h>
#include <sprites/hshot.h>
#include <sprites/rocket.h>
#include <sprites/bird_product.h>
#include <sprites/star_bot.h>
#include <sprites/chicken_bot.h>
#include <sprites/numbers.h>
#include <sprites/bar_levels.h>
#include <man/animations.h>
#include <sys/ai.h>

//==============================================================================
//==============================================================================
// PRIVATE DATA MEMBERS
//==============================================================================
//==============================================================================

//------------------------------------------------------------------------------
// MOTHERSHIP TEMPLATE
//------------------------------------------------------------------------------
// Cannot receive a collision from anything and cannot collide against anything
const Entity_t mothership_tmpl = {                               
   e_type_empty,                                                 // type
   e_cmp_movable | e_cmp_ai | e_cmp_animated | e_cmp_render,     // cmps      
   MOTHERSHIP_X, MOTHERSHIP_Y,                                   // x, y
   SPR_MOTHERSHIP_0_W,                                          // w (in bytes)
   SPR_MOTHERSHIP_0_H,                                          // h (in bytes)    
   -1, 0,                                                        // vx, vy
   spr_mothership_0,                                            // sprite
   sys_ai_behaviour_mothership,                                  // ai_behaviour
   0,                                                            // ai_counter
   man_anim_mothership,                                         // anim
   man_anim_mothership_time,                                    // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};

//------------------------------------------------------------------------------
// CLOUD TEMPLATE
//------------------------------------------------------------------------------
// Cannot receive a collision from anything and cannot collide against anything
const Entity_t cloud_tmpl = {                               
   e_type_empty,                                                 // type
   e_cmp_movable | e_cmp_ai | e_cmp_animated | e_cmp_render,     // cmps      
   MOTHERSHIP_X, MOTHERSHIP_Y,                                   // x, y
   SPR_CLOUD_0_W,                                                // w (in bytes)
   SPR_CLOUD_0_H,                                                // h (in bytes)    
   -1, 0,                                                        // vx, vy
   spr_cloud_0,                                                  // sprite
   sys_ai_behaviour_mothership,                                  // ai_behaviour
   0,                                                            // ai_counter
   man_anim_cloud,                                               // anim
   man_anim_cloud_time,                                          // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};

//------------------------------------------------------------------------------
// MOTHERSHIP LIGHTS TEMPLATE
//------------------------------------------------------------------------------
// Cannot receive a collision from anything and cannot collide against anything
const Entity_t mothership_light_tmpl = {                               
   e_type_empty,                                                 // type
   e_cmp_movable | e_cmp_ai | e_cmp_animated | e_cmp_render,     // cmps      
   MOTHERSHIP_X, MOTHERSHIP_Y,                                   // x, y
   SPR_MOTHERSHIP_LIGHT_0_W,                                     // w (in bytes)
   SPR_MOTHERSHIP_LIGHT_0_H,                                     // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_mothership_light_0,                                       // sprite
   sys_ai_behaviour_autodestroy_by_t,                            // ai_behaviour
   11,                                                           // ai_counter
   man_anim_mothership_light,                                    // anim
   man_anim_mothership_light_time,                               // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};

//------------------------------------------------------------------------------
// CLOUD LIGHTS TEMPLATE
//------------------------------------------------------------------------------
// Cannot receive a collision from anything and cannot collide against anything
const Entity_t cloud_light_tmpl = {                               
   e_type_empty,                                                 // type
   e_cmp_movable | e_cmp_ai | e_cmp_animated | e_cmp_render,     // cmps      
   MOTHERSHIP_X, MOTHERSHIP_Y,                                   // x, y
   SPR_CLOUD_LIGHT_0_W,                                          // w (in bytes)
   SPR_CLOUD_LIGHT_0_H,                                          // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_cloud_light_0,                                            // sprite
   sys_ai_behaviour_autodestroy_by_t,                            // ai_behaviour
   11,                                                           // ai_counter
   man_anim_cloud_light,                                         // anim
   man_anim_mothership_light_time,                               // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};

//------------------------------------------------------------------------------
// MOTHERSHIP ABDUCTION LIGHT TEMPLATE
//------------------------------------------------------------------------------
// Cannot receive a collision from anything and cannot collide against anything
const Entity_t light_tmpl = {                               
   e_type_empty,                                                 // type
   e_cmp_movable | e_cmp_ai | e_cmp_render,                      // cmps      
   MOTHERSHIP_X, MOTHERSHIP_Y + 18,                              // x, y
   SPR_LIGHT_1_W,                                                // w (in bytes)
   SPR_LIGHT_1_H,                                                // h (in bytes)    
   0, 2,                                                         // vx, vy
   spr_light_1,                                                  // sprite
   sys_ai_behaviour_light,                                       // ai_behaviour
   0,                                                            // ai_counter
   0x0000, 0x00,                                                 // anim, anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};


//------------------------------------------------------------------------------
// ALIEN ENEMY 1 TEMPLATE
//------------------------------------------------------------------------------
// Enemies can receive a collision (from bullets) but do not collide against anything 
const Entity_t alien_enemy1_tmpl = {
   e_type_enemy,                                                 // type
   e_cmp_movable  | e_cmp_collider |                             // cmps
   e_cmp_animated | e_cmp_ai | e_cmp_render,                     // cmps
   0,                                                            // x
   LANE2_Y,                                                      // y
   SPR_ENEMIES_ALIEN_00_W,                                       // w (in bytes)
   SPR_ENEMIES_ALIEN_00_H,                                       // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_enemies_alien_00,                                         // sprite
   sys_ai_behaviour_enemy,                                       // ai_behaviour
   0,                                                            // ai_counter   
   man_anim_alien_enemy1,                                        // anim
   man_anim_enemy_time,                                          // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};

//------------------------------------------------------------------------------
// ALIEN ENEMY 2 TEMPLATE
//------------------------------------------------------------------------------
// Enemies can receive a collision (from bullets) but do not collide against anything 
const Entity_t alien_enemy2_tmpl = {
   e_type_enemy,                                                 // type
   e_cmp_movable  | e_cmp_collider |                             // cmps
   e_cmp_animated | e_cmp_ai | e_cmp_render,                     // cmps
   0,                                                            // x
   LANE2_Y,                                                      // y
   SPR_ENEMIES_ALIEN_01_W,                                       // w (in bytes)
   SPR_ENEMIES_ALIEN_01_H,                                       // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_enemies_alien_04,                                         // sprite
   sys_ai_behaviour_enemy,                                       // ai_behaviour
   0,                                                            // ai_counter   
   man_anim_alien_enemy2,                                        // anim
   man_anim_enemy_time,                                          // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};

//------------------------------------------------------------------------------
// ALIEN ENEMY 3 TEMPLATE
//------------------------------------------------------------------------------
// Enemies can receive a collision (from bullets) but do not collide against anything 
const Entity_t alien_enemy3_tmpl = {
   e_type_enemy,                                                 // type
   e_cmp_movable  | e_cmp_collider |                             // cmps
   e_cmp_animated | e_cmp_ai | e_cmp_render,                     // cmps
   0,                                                            // x
   LANE2_Y,                                                      // y
   SPR_ENEMIES_ALIEN_02_W,                                       // w (in bytes)
   SPR_ENEMIES_ALIEN_02_H,                                       // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_enemies_alien_08,                                         // sprite
   sys_ai_behaviour_enemy,                                       // ai_behaviour
   0,                                                            // ai_counter   
   man_anim_alien_enemy3,                                        // anim
   man_anim_enemy_time,                                          // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};

//------------------------------------------------------------------------------
// ALIEN ENEMY 4 TEMPLATE
//------------------------------------------------------------------------------
// Enemies can receive a collision (from bullets) but do not collide against anything 
const Entity_t alien_enemy4_tmpl = {
   e_type_enemy,                                                 // type
   e_cmp_movable  | e_cmp_collider |                             // cmps
   e_cmp_animated | e_cmp_ai | e_cmp_render,                     // cmps
   0,                                                            // x
   LANE2_Y,                                                      // y
   SPR_ENEMIES_ALIEN_03_W,                                       // w (in bytes)
   SPR_ENEMIES_ALIEN_03_H,                                       // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_enemies_alien_12,                                         // sprite
   sys_ai_behaviour_enemy,                                       // ai_behaviour
   0,                                                            // ai_counter   
   man_anim_alien_enemy4,                                        // anim
   man_anim_enemy_time,                                          // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};


//------------------------------------------------------------------------------
// ALIEN MINION 1 TEMPLATE
//------------------------------------------------------------------------------
// Enemies can receive a collision (from bullets) but do not collide against anything 
const Entity_t alien_minion1_tmpl = {
   e_type_enemy,                                                 // type
   e_cmp_movable  | e_cmp_collider |                             // cmps
   e_cmp_animated | e_cmp_ai | e_cmp_render,                     // cmps
   0,                                                            // x
   LANE2_Y,                                                      // y
   SPR_MINIONS_ALIEN_00_W,                                       // w (in bytes)
   SPR_MINIONS_ALIEN_00_H,                                       // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_minions_alien_00,                                         // sprite
   sys_ai_behaviour_enemy,                                       // ai_behaviour
   0,                                                            // ai_counter   
   man_anim_alien_minion1,                                       // anim
   man_anim_enemy_time,                                          // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
//   e_type_enemy                                                  // collides_against 
};


//------------------------------------------------------------------------------
// ALIEN MINION 2 TEMPLATE
//------------------------------------------------------------------------------
// Enemies can receive a collision (from bullets) but do not collide against anything 
const Entity_t alien_minion2_tmpl = {
   e_type_enemy,                                                 // type
   e_cmp_movable  | e_cmp_collider |                             // cmps
   e_cmp_animated | e_cmp_ai | e_cmp_render,                     // cmps
   0,                                                            // x
   LANE2_Y,                                                      // y
   SPR_MINIONS_ALIEN_01_W,                                       // w (in bytes)
   SPR_MINIONS_ALIEN_01_H,                                       // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_minions_alien_04,                                         // sprite
   sys_ai_behaviour_enemy,                                       // ai_behaviour
   0,                                                            // ai_counter   
   man_anim_alien_minion2,                                       // anim
   man_anim_enemy_time,                                          // anim_counter
   0,                                                            // anim_status   
   0                                                             // collides_against   
//   e_type_enemy                                                  // collides_against
};


//------------------------------------------------------------------------------
// ALIEN MINION 3 TEMPLATE
//------------------------------------------------------------------------------
// Enemies can receive a collision (from bullets) but do not collide against anything 
const Entity_t alien_minion3_tmpl = {
   e_type_enemy,                                                 // type
   e_cmp_movable  | e_cmp_collider |                             // cmps
   e_cmp_animated | e_cmp_ai | e_cmp_render,                     // cmps
   0,                                                            // x
   LANE2_Y,                                                      // y
   SPR_MINIONS_ALIEN_02_W,                                       // w (in bytes)
   SPR_MINIONS_ALIEN_02_H,                                       // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_minions_alien_08,                                         // sprite
   sys_ai_behaviour_enemy,                                       // ai_behaviour
   0,                                                            // ai_counter   
   man_anim_alien_minion3,                                       // anim
   man_anim_enemy_time,                                          // anim_counter
   0,                                                            // anim_status   
   0                                                             // collides_against
//   e_type_enemy                                                  // collides_against
};


//------------------------------------------------------------------------------
// ALIEN MINION 4 TEMPLATE
//------------------------------------------------------------------------------
// Enemies can receive a collision (from bullets) but do not collide against anything 
const Entity_t alien_minion4_tmpl = {
   e_type_enemy,                                                 // type
   e_cmp_movable  | e_cmp_collider |                             // cmps
   e_cmp_animated | e_cmp_ai | e_cmp_render,                     // cmps
   0,                                                            // x
   LANE2_Y,                                                      // y
   SPR_MINIONS_ALIEN_00_W,                                       // w (in bytes)
   SPR_MINIONS_ALIEN_00_H,                                       // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_minions_alien_12,                                         // sprite
   sys_ai_behaviour_enemy,                                       // ai_behaviour
   0,                                                            // ai_counter   
   man_anim_alien_minion4,                                       // anim
   man_anim_enemy_time,                                          // anim_counter
   0,                                                            // anim_status   
   0                                                             // collides_against
//   e_type_enemy                                                  // collides_against
};


//------------------------------------------------------------------------------
// HUMAN ENEMY 1 TEMPLATE
//------------------------------------------------------------------------------
// Enemies can receive a collision (from bullets) but do not collide against anything 
const Entity_t human_enemy1_tmpl = {
   e_type_enemy,                                                 // type
   e_cmp_movable  | e_cmp_collider |                             // cmps
   e_cmp_animated | e_cmp_ai | e_cmp_render,                     // cmps
   0,                                                            // x
   LANE2_Y,                                                      // y
   SPR_ENEMIES_HUMAN_00_W,                                       // w (in bytes)
   SPR_ENEMIES_HUMAN_00_H,                                       // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_enemies_human_00,                                         // sprite
   sys_ai_behaviour_enemy,                                       // ai_behaviour
   0,                                                            // ai_counter   
   man_anim_human_enemy1,                                        // anim
   man_anim_enemy_time,                                          // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};

//------------------------------------------------------------------------------
// HUMAN ENEMY 2 TEMPLATE
//------------------------------------------------------------------------------
// Enemies can receive a collision (from bullets) but do not collide against anything 
const Entity_t human_enemy2_tmpl = {
   e_type_enemy,                                                 // type
   e_cmp_movable  | e_cmp_collider |                             // cmps
   e_cmp_animated | e_cmp_ai | e_cmp_render,                     // cmps
   0,                                                            // x
   LANE2_Y,                                                      // y
   SPR_ENEMIES_HUMAN_01_W,                                       // w (in bytes)
   SPR_ENEMIES_HUMAN_01_H,                                       // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_enemies_human_04,                                         // sprite
   sys_ai_behaviour_enemy,                                       // ai_behaviour
   0,                                                            // ai_counter   
   man_anim_human_enemy2,                                        // anim
   man_anim_enemy_time,                                          // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};

//------------------------------------------------------------------------------
// HUMAN ENEMY 3 TEMPLATE
//------------------------------------------------------------------------------
// Enemies can receive a collision (from bullets) but do not collide against anything 
const Entity_t human_enemy3_tmpl = {
   e_type_enemy,                                                 // type
   e_cmp_movable  | e_cmp_collider |                             // cmps
   e_cmp_animated | e_cmp_ai | e_cmp_render,                     // cmps
   0,                                                            // x
   LANE2_Y,                                                      // y
   SPR_ENEMIES_HUMAN_02_W,                                       // w (in bytes)
   SPR_ENEMIES_HUMAN_02_H,                                       // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_enemies_human_08,                                         // sprite
   sys_ai_behaviour_enemy,                                       // ai_behaviour
   0,                                                            // ai_counter   
   man_anim_human_enemy3,                                        // anim
   man_anim_enemy_time,                                          // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};

//------------------------------------------------------------------------------
// HUMAN ENEMY 4 TEMPLATE
//------------------------------------------------------------------------------
// Enemies can receive a collision (from bullets) but do not collide against anything 
const Entity_t human_enemy4_tmpl = {
   e_type_enemy,                                                 // type
   e_cmp_movable  | e_cmp_collider |                             // cmps
   e_cmp_animated | e_cmp_ai | e_cmp_render,                     // cmps
   0,                                                            // x
   LANE2_Y,                                                      // y
   SPR_ENEMIES_HUMAN_03_W,                                       // w (in bytes)
   SPR_ENEMIES_HUMAN_03_H,                                       // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_enemies_human_12,                                         // sprite
   sys_ai_behaviour_enemy,                                       // ai_behaviour
   0,                                                            // ai_counter   
   man_anim_human_enemy4,                                        // anim
   man_anim_enemy_time,                                          // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};


//------------------------------------------------------------------------------
// HUMAN MINION 1 TEMPLATE
//------------------------------------------------------------------------------
// Enemies can receive a collision (from bullets) but do not collide against anything 
const Entity_t human_minion1_tmpl = {
   e_type_enemy,                                                 // type
   e_cmp_movable  | e_cmp_collider |                             // cmps
   e_cmp_animated | e_cmp_ai | e_cmp_render,                     // cmps
   0,                                                            // x
   LANE2_Y,                                                      // y
   SPR_MINIONS_HUMAN_00_W,                                       // w (in bytes)
   SPR_MINIONS_HUMAN_00_H,                                       // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_minions_human_00,                                         // sprite
   sys_ai_behaviour_enemy,                                       // ai_behaviour
   0,                                                            // ai_counter   
   man_anim_human_minion1,                                       // anim
   man_anim_enemy_time,                                          // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
//   e_type_enemy                                                  // collides_against 
};


//------------------------------------------------------------------------------
// HUMAN MINION 2 TEMPLATE
//------------------------------------------------------------------------------
// Enemies can receive a collision (from bullets) but do not collide against anything 
const Entity_t human_minion2_tmpl = {
   e_type_enemy,                                                 // type
   e_cmp_movable  | e_cmp_collider |                             // cmps
   e_cmp_animated | e_cmp_ai | e_cmp_render,                     // cmps
   0,                                                            // x
   LANE2_Y,                                                      // y
   SPR_MINIONS_HUMAN_01_W,                                       // w (in bytes)
   SPR_MINIONS_HUMAN_01_H,                                       // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_minions_human_04,                                         // sprite
   sys_ai_behaviour_enemy,                                       // ai_behaviour
   0,                                                            // ai_counter   
   man_anim_human_minion2,                                       // anim
   man_anim_enemy_time,                                          // anim_counter
   0,                                                            // anim_status   
   0                                                             // collides_against   
//   e_type_enemy                                                  // collides_against
};


//------------------------------------------------------------------------------
// HUMAN MINION 3 TEMPLATE
//------------------------------------------------------------------------------
// Enemies can receive a collision (from bullets) but do not collide against anything 
const Entity_t human_minion3_tmpl = {
   e_type_enemy,                                                 // type
   e_cmp_movable  | e_cmp_collider |                             // cmps
   e_cmp_animated | e_cmp_ai | e_cmp_render,                     // cmps
   0,                                                            // x
   LANE2_Y,                                                      // y
   SPR_MINIONS_HUMAN_02_W,                                       // w (in bytes)
   SPR_MINIONS_HUMAN_02_H,                                       // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_minions_human_08,                                         // sprite
   sys_ai_behaviour_enemy,                                       // ai_behaviour
   0,                                                            // ai_counter   
   man_anim_human_minion3,                                       // anim
   man_anim_enemy_time,                                          // anim_counter
   0,                                                            // anim_status   
   0                                                             // collides_against
//   e_type_enemy                                                  // collides_against
};


//------------------------------------------------------------------------------
// HUMAN MINION 4 TEMPLATE
//------------------------------------------------------------------------------
// Enemies can receive a collision (from bullets) but do not collide against anything 
const Entity_t human_minion4_tmpl = {
   e_type_enemy,                                                 // type
   e_cmp_movable  | e_cmp_collider |                             // cmps
   e_cmp_animated | e_cmp_ai | e_cmp_render,                     // cmps
   0,                                                            // x
   LANE2_Y,                                                      // y
   SPR_MINIONS_HUMAN_00_W,                                       // w (in bytes)
   SPR_MINIONS_HUMAN_00_H,                                       // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_minions_human_12,                                         // sprite
   sys_ai_behaviour_enemy,                                       // ai_behaviour
   0,                                                            // ai_counter   
   man_anim_human_minion4,                                       // anim
   man_anim_enemy_time,                                          // anim_counter
   0,                                                            // anim_status   
   0                                                             // collides_against
//   e_type_enemy                                                  // collides_against
};



//------------------------------------------------------------------------------
// LIVESBOARD PLAYERSHIP TEMPLATE (human avatar)
//
// Scoreboard manager in charge or render the scoreboard (without entities)
//------------------------------------------------------------------------------
// Cannot receive a collision from anything and cannot collide against anything
const Entity_t lives_human_tmpl = {
   e_type_default,                                               // type
   e_cmp_render | e_cmp_animated,                                // cmps
   LIVES_X, LIVES_Y,                                             // x, y
   SPR_LIVES_HUMAN_0_W,                                          // w (in bytes)
   SPR_LIVES_HUMAN_0_H,                                          // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_lives_human_0,                                            // sprite
   0x0000,                                                       // null pointer, no ai_behaviour
   0,                                                            // ai_counter   
   man_anim_player_sit,                                          // anim
   45,                                                           // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against 
};


//------------------------------------------------------------------------------
// LIVESBOARD PLAYERSHIP TEMPLATE (alien avatar)
//
// Scoreboard manager in charge or render the scoreboard (without entities)
//------------------------------------------------------------------------------
// Cannot receive a collision from anything and cannot collide against anything
const Entity_t lives_alien_tmpl = {
   e_type_default,                                               // type
   e_cmp_render | e_cmp_animated,                                // cmps
   LIVES_X, LIVES_Y,                                             // x, y
   SPR_LIVES_ALIEN_0_W,                                          // w (in bytes)
   SPR_LIVES_ALIEN_0_H,                                          // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_lives_alien_0,                                            // sprite
   0x0000,                                                       // null pointer, no ai_behaviour
   0,                                                            // ai_counter   
   man_anim_alien_sit,                                           // anim
   45,                                                           // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against 
};




//------------------------------------------------------------------------------
// PLAYER ZERO TEMPLATE (ai controlled)
//------------------------------------------------------------------------------
// Can receive a collision from enemy shots but cannot collide against anything
const Entity_t player0_tmpl = {
   e_type_player,                                                // type
   e_cmp_movable | e_cmp_ai |                                    // cmps    
   e_cmp_render  | e_cmp_animated | e_cmp_collider,              // cmps
   PLAYER_X,                                                     // x
   PLAYER_Y,                                                     // y
   SPR_PLAYER_00_W,                                              // w (in bytes)
   SPR_PLAYER_00_H,                                              // h (in bytes)    
   -1, 0,                           
   spr_player_00,                                                // sprite
   sys_ai_behaviour_player_zero,   
   0,                                                            // ai_counter
   man_anim_player_waiting,                                      // anim
   man_anim_player_time1,                                        // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};


//------------------------------------------------------------------------------
// PLAYER TEMPLATE (input controlled, human avatar)
//------------------------------------------------------------------------------
// Can receive a collision from enemy shots but cannot collide against anything
const Entity_t human_tmpl = {
   e_type_player,                                                // type
   e_cmp_movable | e_cmp_input |                                 // cmps
   e_cmp_render  | e_cmp_animated | e_cmp_collider,              // cmps
   PLAYER_X,                                                     // x
   PLAYER_Y,                                                     // y
   SPR_PLAYER_00_W,                                              // w (in bytes)
   SPR_PLAYER_00_H,                                              // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_player_00,                                                // sprite
   0x0000,                                                       // null pointer, no ai_behaviour
   0,                                                            // ai_counter
   man_anim_player_waiting,                                      // anim
   man_anim_player_time1,                                        // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};


//------------------------------------------------------------------------------
// PLAYER TEMPLATE (input controlled, alien avatar)
//------------------------------------------------------------------------------
// Can receive a collision from enemy shots but cannot collide against anything
const Entity_t alien_tmpl = {
   e_type_player,                                                // type
   e_cmp_movable | e_cmp_input |                                 // cmps
   e_cmp_render  | e_cmp_animated | e_cmp_collider,              // cmps
   PLAYER_X,                                                     // x
   PLAYER_Y,                                                     // y
   SPR_ALIEN_00_W,                                               // w (in bytes)
   SPR_ALIEN_00_H,                                               // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_alien_00,                                                 // sprite
   0x0000,                                                       // null pointer, no ai_behaviour
   0,                                                            // ai_counter
   man_anim_alien_waiting,                                       // anim
   man_anim_alien_time1,                                         // anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};




//------------------------------------------------------------------------------
// PLAYER VERTICAL SHOT TEMPLATE
//------------------------------------------------------------------------------
// Can receive a collision and can collide against enemies
const Entity_t playervshot_tmpl = {
   e_type_player_vshot,                                          // type
   e_cmp_movable | e_cmp_ai |                                    // cmps
   e_cmp_render  | e_cmp_collider,                               // cmps
   0,                                                            // x 
   PLAYERVSHOT_Y,                                                // y
   SPR_VSHOT_1_W,                                                // w (in bytes)
   SPR_VSHOT_1_H,                                                // h (in bytes)    
   0, -8,                                                        // vx, vy
   spr_vshot_1,                                                  // sprite
   sys_ai_behaviour_autodestroy_by_t,                                 // ai_behaviour
   15,                                                           // ai_counter
   0x0000,                                                       // anim
   0x00,                                                         // anim_counter
   0,                                                            // anim_status
   e_type_enemy                                                  // collides_against
};


//------------------------------------------------------------------------------
// PLAYER HORIZONTAL SHOT TEMPLATE
//------------------------------------------------------------------------------
// Can receive a collision and can collide against enemies
const Entity_t playerhshot_tmpl = {
   e_type_player_hshot,                                          // type
   e_cmp_movable | e_cmp_ai |                                    // cmps
   e_cmp_render  | e_cmp_collider,                               // cmps
   0,                                                            // x 
   PLAYERHSHOT_Y,                                                // y
   SPR_HSHOT_1_W,                                                // w (in bytes)
   SPR_HSHOT_1_H,                                                // h (in bytes)    
   2, 0,                                                         // vx, vy
   spr_hshot_1,                                                  // sprite
   sys_ai_behaviour_autodestroy_by_x,                            // ai_behaviour
   10,                                                           // ai_counter
   0x0000,                                                       // anim
   0x00,                                                         // anim_counter
   0,                                                            // anim_status
   e_type_enemy_bot | e_type_enemy                               // collides_against
};

//------------------------------------------------------------------------------
// ENEMY SHOT 1 TEMPLATE
//------------------------------------------------------------------------------
// Can receive a collision and can collide against enemies
const Entity_t enemyshot1_tmpl = {
   e_type_enemy_shot,                                            // type
   e_cmp_movable | e_cmp_ai |                                    // cmps
   e_cmp_render  | e_cmp_collider,                               // cmps
   0,                                                            // x
   LANE0_Y + SPR_ENEMIES_HUMAN_00_H,                             // y
   SPR_VSHOT_3_W,                                                // w (in bytes)
   SPR_VSHOT_3_H,                                                // h (in bytes)    
   0, 8,                                                         // vx, vy
   spr_vshot_3,                                                  // sprite
   sys_ai_behaviour_autodestroy_by_t,                            // ai_behaviour
   7,                                                            // ai_counter
   0x0000,                                                       // anim
   0x00,                                                         // anim_counter
   0,                                                            // anim_status
   e_type_player                                                 // collides_against
};


//------------------------------------------------------------------------------
// ENEMY SHOT 2 TEMPLATE
//------------------------------------------------------------------------------
// Can receive a collision and can collide against enemies
const Entity_t enemyshot2_tmpl = {
   e_type_enemy_shot,                                            // type
   e_cmp_movable | e_cmp_ai |                                    // cmps
   e_cmp_render  | e_cmp_collider,                               // cmps
   0,                                                            // x
   LANE0_Y + SPR_ENEMIES_HUMAN_01_H,                             // y
   SPR_VSHOT_3_W,                                                // w (in bytes)
   SPR_VSHOT_3_H,                                                // h (in bytes)    
   0, 8,                                                         // vx, vy
   spr_vshot_2,                                                  // sprite
   sys_ai_behaviour_autodestroy_by_t,                            // ai_behaviour
   7,                                                            // ai_counter
   0x0000,                                                       // anim
   0x00,                                                         // anim_counter
   0,                                                            // anim_status
   e_type_player                                                 // collides_against
};

//------------------------------------------------------------------------------
// EGG SHOT 1 TEMPLATE
//------------------------------------------------------------------------------
// Can receive a collision and can collide against enemies
const Entity_t eggshot1_tmpl = {
   e_type_enemy_shot,                                            // type
   e_cmp_movable | e_cmp_ai |                                    // cmps
   e_cmp_render  | e_cmp_collider,                               // cmps
   0,                                                            // x
   LANE0_Y + SPR_ENEMIES_HUMAN_00_H,                             // y
   SPR_EGGS_1_W,                                                // w (in bytes)
   SPR_EGGS_1_H,                                                // h (in bytes)    
   0, 8,                                                         // vx, vy
   spr_eggs_1,                                                   // sprite
   sys_ai_behaviour_autodestroy_by_t,                            // ai_behaviour
   7,                                                            // ai_counter
   0x0000,                                                       // anim
   0x00,                                                         // anim_counter
   0,                                                            // anim_status
   e_type_player                                                 // collides_against
};


//------------------------------------------------------------------------------
// EGG SHOT 2 TEMPLATE
//------------------------------------------------------------------------------
// Can receive a collision and can collide against enemies
const Entity_t eggshot2_tmpl = {
   e_type_enemy_shot,                                            // type
   e_cmp_movable | e_cmp_ai |                                    // cmps
   e_cmp_render  | e_cmp_collider,                               // cmps
   0,                                                            // x
   LANE0_Y + SPR_ENEMIES_HUMAN_00_H,                             // y
   SPR_EGGS_2_W,                                                // w (in bytes)
   SPR_EGGS_2_H,                                                // h (in bytes)    
   0, 8,                                                         // vx, vy
   spr_eggs_2,                                                   // sprite
   sys_ai_behaviour_autodestroy_by_t,                            // ai_behaviour
   7,                                                            // ai_counter
   0x0000,                                                       // anim
   0x00,                                                         // anim_counter
   0,                                                            // anim_status
   e_type_player                                                 // collides_against
};


//------------------------------------------------------------------------------
// ENEMY ROCKET TEMPLATE
//------------------------------------------------------------------------------
// Can receive a collision and can collide against enemies
const Entity_t enemyrocket_tmpl = {
   e_type_enemy_shot,                                            // type
   e_cmp_movable | e_cmp_ai |                                    // cmps
   e_cmp_render  | e_cmp_collider,                               // cmps
   0,                                                            // x
   LANE0_Y + SPR_ENEMIES_HUMAN_02_H,                             // y
   SPR_ROCKET_1_W,                                               // w (in bytes)
   SPR_ROCKET_1_H,                                               // h (in bytes)    
   0, 4,                                                         // vx, vy
   spr_rocket_1,                                                 // sprite
   sys_ai_behaviour_autodestroy_by_t,                            // ai_behaviour
   12,                                                           // ai_counter
   0x0000,                                                       // anim
   0x00,                                                         // anim_counter
   0,                                                            // anim_status
   e_type_player                                                 // collides_against
};


//------------------------------------------------------------------------------
// BIRD PRODUCT TEMPLATE
//------------------------------------------------------------------------------
// Can receive a collision and can collide against enemies
const Entity_t bird_product_tmpl = {
   e_type_enemy_shot,                                            // type
   e_cmp_movable | e_cmp_ai |                                    // cmps
   e_cmp_render  | e_cmp_collider,                               // cmps
   0,                                                            // x
   LANE0_Y + SPR_ENEMIES_HUMAN_02_H,                             // y
   SPR_BIRD_PRODUCT_1_W,                                         // w (in bytes)
   SPR_BIRD_PRODUCT_1_H,                                         // h (in bytes)    
   0, 4,                                                         // vx, vy
   spr_bird_product_1,                                           // sprite
   sys_ai_behaviour_autodestroy_by_t,                            // ai_behaviour
   12,                                                           // ai_counter
   0x0000,                                                       // anim
   0x00,                                                         // anim_counter
   0,                                                            // anim_status
   e_type_player                                                 // collides_against
};


//------------------------------------------------------------------------------
// ENEMY BOT TEMPLATE
//------------------------------------------------------------------------------
// Can receive a collision and can collide against enemies
const Entity_t enemybot_tmpl = {
   e_type_enemy_bot,                                             // type
   e_cmp_movable | e_cmp_ai |                                    // cmps
   e_cmp_render  | e_cmp_collider,                               // cmps
   0,                                                            // x
   LANE0_Y + SPR_ENEMIES_HUMAN_03_H - 2,                         // y
   SPR_STAR_BOT_0_W,                                             // w (in bytes)
   SPR_STAR_BOT_0_H,                                             // h (in bytes)    
   0, 4,                                                         // vx, vy
   spr_star_bot_1,                                               // sprite
   sys_ai_behaviour_bot,                                         // ai_behaviour
   0,                                                            // ai_counter
   man_anim_starbot,                                             // anim
   man_anim_starbot_time,                                        // anim_counter
   0,                                                            // anim_status
   e_type_player                                                 // collides_against
};

//------------------------------------------------------------------------------
// CHICKEN BOT TEMPLATE
//------------------------------------------------------------------------------
// Can receive a collision and can collide against enemies
const Entity_t chickenbot_tmpl = {
   e_type_enemy_bot,                                             // type
   e_cmp_movable | e_cmp_ai |                                    // cmps
   e_cmp_render  | e_cmp_collider,                               // cmps
   0,                                                            // x
   LANE0_Y + SPR_ENEMIES_HUMAN_03_H - 2,                         // y
   SPR_CHICKEN_BOT_0_W,                                          // w (in bytes)
   SPR_CHICKEN_BOT_0_H,                                          // h (in bytes)    
   0, 4,                                                         // vx, vy
   spr_chicken_bot_1,                                            // sprite
   sys_ai_behaviour_bot,                                         // ai_behaviour
   0,                                                            // ai_counter
   man_anim_chickenbot,                                             // anim
   man_anim_chickenbot_time,                                        // anim_counter
   0,                                                            // anim_status
   e_type_player                                                 // collides_against
};




//------------------------------------------------------------------------------
// DIGIT TEMPLATE
//------------------------------------------------------------------------------
// Just shows the number...
const Entity_t digit_tmpl = {
   e_type_default,                                               // type
   e_cmp_render,                                                 // cmps
   SCOREBOARD_X,                                                 // x
   SCOREBOARD_Y,                                                 // y
   SPR_NUMBER_00_W,                                              // w (in bytes)
   SPR_NUMBER_00_H,                                              // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_number_00,                                                // sprite
   0x0000,                                                       // null pointer, no ai_behaviour
   0,                                                            // ai_counter
   0x0000, 0x00,                                                 // anim, anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};


//------------------------------------------------------------------------------
// PLAYER WEAPON TEMPERATURE BAR TEMPLATE
//------------------------------------------------------------------------------
// Just shows the number...
/*
// Render with drawbox instead of sprite
const Entity_t bar_tmpl = {
   e_type_default,                                               // type
   e_cmp_movable | e_cmp_ai | e_cmp_render,                      // cmps
   TEMP_BAR_X,                                                   // x
   TEMP_BAR_Y,                                                   // y
   4,                                                            // w (in bytes)
   8,                                                            // h (in bytes)    
   0, 0,                                                         // vx, vy
   0x0000,                                                       // sprite
   sys_ai_behaviour_bar,                                         // ai_behaviour
   0,                                                            // ai_counter
   0x0000, 0x00,                                                 // anim, anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};
*/
// Render with sprite instead of draw box
const Entity_t bar_tmpl = {
   e_type_default,                                               // type
   e_cmp_movable | e_cmp_ai | e_cmp_render,                      // cmps
   TEMP_BAR_X,                                                   // x
   TEMP_BAR_Y,                                                   // y
   SPR_BAR_LEVEL_1_W,                                            // w (in bytes)
   SPR_BAR_LEVEL_1_H,                                            // h (in bytes)    
   0, 0,                                                         // vx, vy
   spr_bar_level_1,                                              // sprite (green)
   sys_ai_behaviour_bar,                                         // ai_behaviour
   0,                                                            // ai_counter
   0x0000, 0x00,                                                 // anim, anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};

//------------------------------------------------------------------------------
// FLASH TEMPLATE
//------------------------------------------------------------------------------
// Empty template with just an ai flash behaviour with a timer to autodestroy
const Entity_t flash_tmpl = {
   e_type_empty,                                                 // type
   e_cmp_ai,                                                     // cmps
   0,                                                            // x
   0,                                                            // y
   0,                                                            // w (in bytes)
   0,                                                            // h (in bytes)    
   0, 0,                                                         // vx, vy
   0x0000,                                                       // sprite (green)
   sys_ai_behaviour_flash,                                       // ai_behaviour
   35,                                                           // ai_counter
   0x0000, 0x00,                                                 // anim, anim_counter
   0,                                                            // anim_status
   0                                                             // collides_against
};
