//-----------------------------LICENSE NOTICE------------------------------------
//
////////////////////////////////////////////////////////////////////////////////
///////////////////////////  SHOOT AND RUN /////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
//
//  Code & Graphics Copyright (C) 2020 Rafa Gutierrez (rafagutierrez@qq.com)
//
//  This file is part of Shoot and run: an Amstrad CPC Game made with CPCTelera
//  for CPCRetroDev 2020
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.


#pragma once                    // to avoid including several times
#include <cpctelera.h>
#include <man/entity.h>


// Macros
#define OnGoingAttack  (e_type_player_vshot | e_type_player_hshot | e_type_enemy_shot | e_type_enemy_bot)


//==============================================================================
// PUBLIC CONSTANTS
//==============================================================================
//
#define EASY              0
#define NORMAL            1
#define HARDCORE          2

#define HUMAN             1
#define ALIEN             0
#define MUSIC_ON          0           // for debugging
#define NUM_PLAYERS       1           // num_players == 0 --> plays by itself
#define FIRST_LVL         0           // for debugging
#define CYCLE_DELAY       2           
#define AFTER_HIT_TIME   10           // time since player death animation finish and ready to play
#define MAX_ENEMIES_LVL   5           // minions does not count to pass lvl, but give points too
#define MAX_BAR_LEVEL    14
#define SHOT_LEFT         1
#define SHOT_RIGHT        2
#define VSHOT             1
#define HSHOT             0
#define SPLIT_LEVEL       4

#define GROUND_Y        178

//==============================================================================
// PUBLIC DATA STRUCTURES
//==============================================================================
extern u8 m_level;                      // Current level   
extern u8 m_player_x;                   // Player x position 
extern u8 m_lane0_enemy_x;              // Shooter x position
extern u8 m_star;                       // 0: no star 2: star on right of player 1: star on left of player 
extern u8 m_player_vshot;               // Player vshot flag
extern u8 m_player_lhshot;              // Player left hshot flag   
extern u8 m_player_rhshot;              // Player right hshot flag   
extern u8 m_enemy_shot;                 // Enemy shot flag 
extern u8 m_enemy_bot;                  // Enemy bot flag 
extern u8 m_enemy_bounces;              // Enemies bouncing flag (does not include mothership)
extern u8 m_enemy_hides;                // Enemies temporary hide flag
extern u8 m_bar_lvl;                    // Player weapon temperature level
extern u8 m_lane_status[3];             // 00: empty, 01: one enemy, 10: two minions, 11: one minion
extern u8 m_abduction_light;            // Mothership abduction light catched the player
extern u8 m_player_avatar;              // Player is human or alien
extern u8 music_on;
extern u8 m_difficulty;                 // 0: Easy    1: Normal (smarter shooter)    2: Hardcore (crazy bot deployment)


//==============================================================================
// PUBLIC INTERFACE
//==============================================================================
void  man_game_init();
void  man_game_play();
void  man_game_reset();
void  man_game_create_enemy(Entity_t const* e_mother);
void  man_game_enemy_lane_down(Entity_t* e_enemy);
void  man_game_entity_destroy(Entity_t* e);
void  man_game_player_hit(Entity_t* e_player);
void  man_game_enemy_hit(Entity_t* e_enemy);
void  man_game_bot_hit(Entity_t* e_enemy);
void  man_game_destroy_player_shot(Entity_t* e);
void  man_game_player_reset(Entity_t* e);
void  man_game_player_vshot(Entity_t* e_player);
void  man_game_player_hshot(Entity_t* e_player, u8 direction);
void  man_game_enemy_attack(Entity_t* e_enemy);
void  man_game_shadow_eraser(Entity_t* original, u8 const * spr_shadow);          
//void  man_game_death_animation(Entity_t* e, u8 duration);

u8    man_game_check_lane(u8 y);
Entity_t* man_game_create_template_entity(const Entity_t* templ_e);

void wait_game_cycles(u8 cycles);
void wait(u8 n);

void man_game_cleanup_attacks();