//-----------------------------LICENSE NOTICE------------------------------------
//
////////////////////////////////////////////////////////////////////////////////
///////////////////////////  SHOOT AND RUN /////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
//
//  Code & Graphics Copyright (C) 2020 Rafa Gutierrez (rafagutierrez@qq.com)
//
//  This file is part of Shoot and run: an Amstrad CPC Game made with CPCTelera
//  for CPCRetroDev 2020
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.


#include <man/livesboard.h>
#include <man/entity.h>
#include <man/game.h>
#include <sprites/lives_human.h>
#include <sprites/new_player.h>  
#include "entity_templates.h"


//==============================================================================
// PRIVATE DATA MEMBERS
//==============================================================================
// do not initialize global variables (SDCC issue RAM/ROM)
//LivesBoard_t lb;
u8          lives_left;
Entity_t*   live[MAX_LIVES];


//==============================================================================
// PUBLIC FUNCTIONS
//==============================================================================

////////////////////////////////////////////////////////////////////////////////
// LIVESBOARD INIT
//
// Player starts with 3 lives
//
void man_livesboard_create(const Entity_t* template) {
   u8 x = LIVES_X;
   u8 w = template->w;

   lives_left = 4;                              // leave room for the extra life

   for (u8 i=0; i<MAX_LIVES; i++) {
//      live[i] = man_entity_create_from_template(&lives_tmpl);
      live[i] = man_entity_create_from_template(template);
      live[i]->x += i*(w + LIVES_DX);
   } 
   live[3]->cmps ^= e_cmp_render;              // extra lives keeps hidden for now

}

////////////////////////////////////////////////////////////////////////////////
// EXTRA LIFE
//
// Player can get an extra life every 10.000 points in case he does not have 4 lives already
//
void man_livesboard_extra_life() {
   u8 x = LIVES_X;
   u8 i = lives_left-1;

   if (i < 4) {
      live[i]->cmps  |= (e_cmp_render | e_cmp_animated);
      live[i]->sprite = live[i]->anim->val.sprite;
      lives_left++;
   }

}

////////////////////////////////////////////////////////////////////////////////
// LIVESBOARD UPDATE
//
//
void man_livesboard_update() {
   
   if ((--lives_left) > 0) {
      live[lives_left-1]->sprite = spr_lives_human_2;  // empty one                
      live[lives_left-1]->cmps &= ~e_cmp_animated;
   }
   else 
      lives_left = 0;

}   


////////////////////////////////////////////////////////////////////////////////
// LIVESBOARD UPDATE
//
//
u8 man_livesboard_check() {
   
   return lives_left;

}