//-----------------------------LICENSE NOTICE------------------------------------
//
////////////////////////////////////////////////////////////////////////////////
///////////////////////////  SHOOT AND RUN /////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
//
//  Code & Graphics Copyright (C) 2020 Rafa Gutierrez (rafagutierrez@qq.com)
//
//  This file is part of Shoot and run: an Amstrad CPC Game made with CPCTelera
//  for CPCRetroDev 2020
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.


#include <cpctelera.h>
#include "menu.h"
#include <man/game.h>
#include <string.h>
#include <sys/input.h>
#include <sprites/palette_0.h>


#include <man/entity.h>
#include <sys/ai.h>
#include <sys/physics.h>
#include <sys/animations.h>
#include <sys/render.h>
#include "entity_templates.h"



#define SCREEN_TOP_LEFT          cpctm_screenPtr (CPCT_VMEM_START,  0, 0)
#define SCREEN_TITLE_START       cpctm_screenPtr (CPCT_VMEM_START,  8, 10)
#define SCREEN_MENU_TOPLEFT      cpctm_screenPtr (CPCT_VMEM_START, 0, 50)
#define SCREEN_MENU_START        cpctm_screenPtr (CPCT_VMEM_START, 8, 50)
#define SCREEN_BOTTOM_CENTER     cpctm_screenPtr (CPCT_VMEM_START, 26, 180)
#define HUMAN_X                  36-10
#define ALIEN_X                  36+10

u8 start_game;

//==============================================================================
// PUBLIC DATA MEMBERS
//==============================================================================
// do not initialize global variables (SDCC issue RAM/ROM)


//==============================================================================
// PRIVATE DATA MEMBERS
//==============================================================================


//==============================================================================
// PRIVATE FUNCTIONS
//==============================================================================

void pause(u8 seconds) {

    for (u8 i=0; i<seconds; i++) {
        cpct_waitHalts(250);
        cpct_waitHalts(50);
   }

}

void waitReturn() {

   cpct_drawStringM0("PRESS ENTER TO CONTINUE", SCREEN_BOTTOM_CENTER);
   // Is enter pressed?
   while (!cpct_isKeyPressed(Key_Return)) {
      cpct_scanKeyboard();
   } 
}

void waitForKey() {

   //cpct_drawStringM0("PRESS ANY KEY TO CONTINUE", SCREEN_BOTTOM_CENTER);
    while (!cpct_isAnyKeyPressed ()) {
      cpct_scanKeyboard();
   }
}


void update_systems() {
   //sys_ai_update();
   //sys_physics_update();

   sys_animation_update();   

   cpct_waitHalts(2);         // cpu stops until next interruption (2 times)
   cpct_waitVSYNC();          // active wait until VSYNC flag = 1 (lowest part of the screen)   
   cpct_waitHalts(2);         // cpu stops until next interruption (2 times)
   cpct_waitVSYNC();          // active wait until VSYNC flag = 1 (lowest part of the screen)   

   sys_render_update();         
   man_entity_update();
}


//==============================================================================
// PUBLIC FUNCTIONS
//==============================================================================

////////////////////////////////////////////////////////////////////////////////
// INIT THE MENU
//    
void man_menu_init() {

   start_game = 0;
     
   man_entity_init();

   sys_input_init();
   sys_ai_init();
   sys_render_init(); 

   // default values
   m_difficulty = EASY;
   m_player_avatar = HUMAN;


}


////////////////////////////////////////////////////////////////////////////////
// CLEAR MENU
//
// Clears the input number of lines
//
void clear_menu(u8 lines) {
   u8* pvmem = SCREEN_MENU_TOPLEFT;  

   cpct_drawSolidBox(pvmem, 0, 40, 8*lines);             
   pvmem += 40;                                          // CPC screen width = 80 bytes, so 2nd half is 40 bytes to the right
   cpct_drawSolidBox(pvmem, 0, 40, 8*lines);

}




////////////////////////////////////////////////////////////////////////////////
// REDRAW SUBMENU DIFFICULTY
//
void redraw_difficulty() {
   const u8 *text1   = "E EASY";
   const u8 *text2   = "N NORMAL";
   const u8 *text3   = "H HARDCORE";
   const u8 *text4   = "B BACK";
   u8* pvmem1 = SCREEN_MENU_START;  
   u8* pvmem2 = pvmem1 + 0xA0;  
   u8* pvmem3 = pvmem2 + 0xA0;  
   u8* pvmem4 = pvmem3 + 0xA0 + 0xA0;  

   // redraw the menu
   if (m_difficulty == EASY)           cpct_setDrawCharM0(2,0);       // fg white, bg black
   else                                cpct_setDrawCharM0(1,0);       // fg cyan,  bg black
   cpct_drawStringM0(text1, pvmem1); 

   if (m_difficulty == NORMAL)         cpct_setDrawCharM0(2,0);       // fg white, bg black
   else                                cpct_setDrawCharM0(1,0);       // fg cyan,  bg black
   cpct_drawStringM0(text2, pvmem2); 

   if (m_difficulty == HARDCORE)       cpct_setDrawCharM0(2,0);       // fg white, bg black
   else                                cpct_setDrawCharM0(1,0);       // fg cyan,  bg black
   cpct_drawStringM0(text3, pvmem3); 

   cpct_setDrawCharM0(1,0);                                           // fg cyan,  bg black
   cpct_drawStringM0(text4, pvmem4); 

}

////////////////////////////////////////////////////////////////////////////////
// SUBMENU DIFFICULTY
//
void menu_difficulty() {
   u8 go_back = 0;

   redraw_difficulty();
   while (!go_back) {
      // update input
      cpct_scanKeyboard();
      while (!cpct_isAnyKeyPressed()) {
         cpct_scanKeyboard();
      }

      if (cpct_isKeyPressed(Key_B)) go_back = 1;
      else {
         // update the difficulty
         if  (cpct_isKeyPressed(Key_E)) {
            m_difficulty    = EASY;
            redraw_difficulty();
         }
         else if (cpct_isKeyPressed(Key_N)) {
            m_difficulty    = NORMAL;
            redraw_difficulty();
         }
         else if (cpct_isKeyPressed(Key_H)) {
            m_difficulty    = HARDCORE;
           redraw_difficulty();
         }
      }
   }
   
   clear_menu((2*5)-1);
   main_menu();

}


////////////////////////////////////////////////////////////////////////////////
// REDRAW SUBMENU INSTRUCTIONS
//
void redraw_keys() {
   const u8 *text1   = "LEFT          O";
   const u8 *text2   = "RIGHT         P";
   const u8 *text3   = "UP            Q";
   const u8 *text4   = "FIRE      SPACE";
   const u8 *text5   = "B BACK";
   u8* pvmem1 = SCREEN_MENU_START;  
   u8* pvmem2 = pvmem1 + 0xA0;  
   u8* pvmem3 = pvmem2 + 0xA0;  
   u8* pvmem4 = pvmem3 + 0xA0;  
   u8* pvmem5 = pvmem4 + 0xA0;  

   // redraw the menu

   cpct_setDrawCharM0(2,0);            // fg white, bg black
   cpct_drawStringM0(text1, pvmem1); 
   cpct_drawStringM0(text2, pvmem2); 
   cpct_drawStringM0(text3, pvmem3); 
   cpct_drawStringM0(text4, pvmem4); 
   
   cpct_setDrawCharM0(1,0);            // fg cyan,  bg black
   cpct_drawStringM0(text5, pvmem5); 
}


////////////////////////////////////////////////////////////////////////////////
// SUBMENU KEYS
//
void menu_keys() {
   u8 go_back = 0;

   redraw_keys();

   while (!go_back) {
      // update input
      cpct_scanKeyboard();
      while (!cpct_isAnyKeyPressed()) {
         cpct_scanKeyboard();
      }

      if (cpct_isKeyPressed(Key_B)) go_back = 1;
   }
   
   clear_menu((2*5)-1);
   main_menu();

}


////////////////////////////////////////////////////////////////////////////////
// REDRAW SUBMENU CREDITS
//
void redraw_credits() {
   const u8 *text1   = "CODE & GFX";
   const u8 *text2   = "RAFA GUTIERREZ";
   const u8 *text3   = "B BACK";
   u8* pvmem1 = SCREEN_MENU_START;  
   u8* pvmem2 = pvmem1 + 0xA0;  
   u8* pvmem3 = pvmem2 + 0xA0 + 0xA0 + 0xA0;  


   // redraw the menu

   cpct_setDrawCharM0(2,0);            // fg white, bg black
   cpct_drawStringM0(text1, pvmem1); 
   cpct_drawStringM0(text2, pvmem2); 
   
   cpct_setDrawCharM0(1,0);            // fg cyan,  bg black
   cpct_drawStringM0(text3, pvmem3); 
}





////////////////////////////////////////////////////////////////////////////////
// SUBMENU CREDITS
//
void menu_credits() {
   u8 go_back = 0;

   redraw_credits();

   while (!go_back) {
      // update input
      cpct_scanKeyboard();
      while (!cpct_isAnyKeyPressed()) {
         cpct_scanKeyboard();
      }

      if (cpct_isKeyPressed(Key_B)) go_back = 1;
   }
   
   clear_menu((2*5)-1);
   main_menu();

}


////////////////////////////////////////////////////////////////////////////////
// SHOW THE MENU
//    
void main_menu() {
   Entity_t* human;
   Entity_t* alien;

   u8* pvmem = SCREEN_MENU_START;  

   const u8 *text0   = "SHOOT AND RUN";
   const u8 *text1   = "1 HUMAN";
   const u8 *text2   = "2 ALIEN";
   const u8 *text3   = "3 DIFFICULTY";
   const u8 *text4   = "4 INSTRUCTIONS";
   const u8 *text5   = "5 CREDITS";

   cpct_setDrawCharM0(3,0);       // fg cyan,  bg black
   cpct_drawStringM0(text0, SCREEN_TITLE_START);

   cpct_setDrawCharM0(1,0);       // fg cyan,  bg black
   cpct_drawStringM0(text1, pvmem); pvmem += 0xA0;
   cpct_drawStringM0(text2, pvmem); pvmem += 0xA0;
   cpct_drawStringM0(text3, pvmem); pvmem += 0xA0;
   cpct_drawStringM0(text4, pvmem); pvmem += 0xA0;
   cpct_drawStringM0(text5, pvmem); pvmem += 0xA0;
   
   human = man_entity_create_from_template(&human_tmpl);
   human->x = HUMAN_X;
   human->anim = man_anim_player_show_off;
   alien = man_entity_create_from_template(&alien_tmpl);
   alien->x = ALIEN_X;
   alien->anim = man_anim_alien_show_off;


   while (!start_game) {

      update_systems(); 

      // update input
      cpct_scanKeyboard_f();
      if (cpct_isKeyPressed(Key_1)) { 
         m_player_avatar = 1;
         human->anim = man_anim_player_dancing;
         alien->anim = man_anim_alien_sit;
         for (u8 i=0; i<60; i++) update_systems(); 
         start_game = 1;
         man_entity_forall( man_entity_set4destruction );        // destroy all entities
      }
      if (cpct_isKeyPressed(Key_2)) {
         m_player_avatar = 0;
         human->anim = man_anim_player_sit;
         alien->anim = man_anim_alien_dancing;
         for (u8 i=0; i<60; i++) update_systems(); 
         start_game = 1;
         man_entity_forall( man_entity_set4destruction );        // destroy all entities
      }
      if (cpct_isKeyPressed(Key_3)) {                            // difficulty menu
         clear_menu((2*5)-1);
         menu_difficulty();
         man_entity_forall( man_entity_set4destruction );        // destroy all entities
      }

      if (cpct_isKeyPressed(Key_4)) {                            // instructions
         clear_menu((2*5)-1);
         menu_keys();
         man_entity_forall( man_entity_set4destruction );        // destroy all entities
      }

      if (cpct_isKeyPressed(Key_5)) {                            // instructions
         clear_menu((2*5)-1);
         menu_credits();
         man_entity_forall( man_entity_set4destruction );        // destroy all entities
      }


   }

}




void man_menu_show() {

    main_menu();

}
