//-----------------------------LICENSE NOTICE------------------------------------
//
////////////////////////////////////////////////////////////////////////////////
///////////////////////////  SHOOT AND RUN /////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
//
//  Code & Graphics Copyright (C) 2020 Rafa Gutierrez (rafagutierrez@qq.com)
//
//  This file is part of Shoot and run: an Amstrad CPC Game made with CPCTelera
//  for CPCRetroDev 2020
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.


#include <man/scoreboard.h>
#include <man/livesboard.h>
#include <man/game.h>
#include <man/entity.h>
#include <sprites/numbers.h>
#include "entity_templates.h"

//==============================================================================
// PRIVATE DATA MEMBERS
//==============================================================================
// do not initialize global variables (SDCC issue RAM/ROM)
ScoreDigit_t d[6]; 


//==============================================================================
// PRIVATE FUNCTIONS
//==============================================================================

////////////////////////////////////////////////////////////////////////////////
// UPDATE DIGIT
//      
//  Check if there is overflow and updates the value and the sprite of the digit
//
// Return value: overflow flag
//
u8 update_digit (ScoreDigit_t* d) {
    u8 overflow = (d->val > 9);                              
    u8 const * spr_number[10] = {
        spr_number_00, spr_number_01, spr_number_02, spr_number_03, spr_number_04,
        spr_number_05, spr_number_06, spr_number_07, spr_number_08, spr_number_09
    };
    
    if (overflow) d->val -=10;

    d->e->sprite = spr_number[d->val]; 
    
    return overflow;
}


//==============================================================================
// PUBLIC FUNCTIONS
//==============================================================================

////////////////////////////////////////////////////////////////////////////////
// INIT
//      Initializes the entity manager. Zeroes everything
//
// Note:
//      On the screen d[0] d[1] d[2] d[3] d[4] d[5]
//
void man_scoreboard_create() {

    // Create the 6 entities for the 6 digits
    u8 i = 5;
    u8 x = SCOREBOARD_X + (6*(SCOREBOARD_DX));
    
    do {
        d[i].val = 0;
        d[i].e = man_entity_create_from_template(&digit_tmpl);
        x -= SCOREBOARD_DX;
        d[i].e->x = x;
        d[i].e->sprite = spr_number_00;
        i--;
    } while (x != SCOREBOARD_X);

}

////////////////////////////////////////////////////////////////////////////////
//  SET THE SCOREBOARD VALUE
//      
//  Adds each digit its carry and updates all the digits of the scoreboard with 
//  the right value and sprite
//
//  Input: c5, c4, c3, c2, c1, c0 are the carries for each digit
//
//  After creation:                     Parameters
//      Add 21 to current value         0,0,0,0,2,1
//      Add 10 to current value         0,0,0,0,1,0
//
//  Note:
//  Max value of the scoreboard: 999999 
//  If we add 10 to that value :  000009
//
void man_scoreboard_set(u8 c5, u8 c4, u8 c3, u8 c2, u8 c1, u8 c0) {
    u8 i = 6;
    u8 c[6]={c0, c1, c2, c3, c4, c5};

    while ( i > 0) {
        --i;
        d[i].val += c[5-i];                             // add carry
        c[6-i] += update_digit(&d[i]);
        //if (c[6-i] == 0) return;                      // optimization in case we only add values < 100
    }
   // if (c[4] == 1) man_livesboard_extra_life();         // Every time c3 == 1 means player scored 10.000 points
    if (c[3] == 1) man_livesboard_extra_life();         // Every time c3 == 1 means player scored 1.000 points
   // if (c[2] == 1) man_livesboard_extra_life();         // Every time c3 == 1 means player scored 100 points  

}