//-----------------------------LICENSE NOTICE------------------------------------
//
////////////////////////////////////////////////////////////////////////////////
///////////////////////////  SHOOT AND RUN /////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
//
//  Code & Graphics Copyright (C) 2020 Rafa Gutierrez (rafagutierrez@qq.com)
//
//  This file is part of Shoot and run: an Amstrad CPC Game made with CPCTelera
//  for CPCRetroDev 2020
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.


#pragma once                    // to avoid including several times
#include <cpctelera.h>
#include <man/entity.h>


//==============================================================================
// PUBLIC DATA STRUCTURES
//==============================================================================

//------------------------------------------------------------------------------
// Forward declarations of structures and type definitions
// Score Digits Structure
typedef struct ScoreDigit_t ScoreDigit_t;   

struct ScoreDigit_t {
    u8                  val;                   
    Entity_t*           e;
};

extern ScoreDigit_t d[6];


//==============================================================================
// PUBLIC INTERFACE
//==============================================================================
void man_scoreboard_create();
void man_scoreboard_set(u8 c5, u8 c4, u8 c3, u8 c2, u8 c1, u8 c0);

/*
    Scoreboard is an array of 6 digits that represents (units, tens, hundreds, etc). 
    Each digit needs the following information:
        - Value (0..9)
        - Pointer to a sprite that shows that value
        - x, y pos

    The scoreboard will need to be updated only when player kills an enemy

    We need a function for:
        - Create the scoreboard
        - Update the scoreboard (in this case just add 21 or 10)
    
    No need a function to show the scoreboard since the scoreboard is composed by
    entities that would be rendered by the render system
*/