//-----------------------------LICENSE NOTICE------------------------------------
//
////////////////////////////////////////////////////////////////////////////////
///////////////////////////  SHOOT AND RUN /////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
//
//  Code & Graphics Copyright (C) 2020 Rafa Gutierrez (rafagutierrez@qq.com)
//
//  This file is part of Shoot and run: an Amstrad CPC Game made with CPCTelera
//  for CPCRetroDev 2020
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.


#include "animations.h"
#include <sys/input.h>
#include <man/animations.h>
#include <man/entity.h>

//==============================================================================
//==============================================================================
// PRIVATE FUNCTIONS
//==============================================================================
//==============================================================================

////////////////////////////////////////////////////////////////////////////////
// CALCULATE ANIM STATUS
//      Calculate the status of an entity
// Inputs:
//      e: Pointer to the entity 
//
// sys_inputs_status
// 0000 No    key pressed
// 0001 Left  key pressed
// 0010 Right key pressed
// 0100 Up    key pressed
// 1000 Fire  key pressed
//u8 calculateAnimStatus(Entity_t* e) {
//    u8 status = 0;
//
//    status = sys_input_status;
//    
//    return status;
//
//}


////////////////////////////////////////////////////////////////////////////////
// UPDATE ONE ENTITY
//      Updates animations of a given entity
// Inputs:
//      e: Pointer to the entity to be updated
//
// Since we use the signature e_cmps_animated in the call from forall_matching 
// in animation_update, we know that all the entities passed as parameters have 
// e_cmp_animated = 1
void sys_animation_update_one_entity(Entity_t* e) {
    u8 current_status = e->anim_status;
    u8 new_status     = sys_input_status; //calculateAnimStatus(e);
    
    if (e->anim == 0x00) {
        cpct_setBorder(HW_GREEN);
        return;
    }

// for now only player might have the animation changed
if (e->type == e_type_player) {
    // Check if animation status is the same as before
    if (current_status !=  new_status) {
 
        // New animation
        e->anim_status = new_status;                          // Update status
        e->anim = man_animations_getAnim(new_status);         // Update pointer to the animation
        // Load next sprite from animation
        e->sprite       = e->anim->val.sprite;   
        e->anim_counter = e->anim->time;                      // reset anim counter
        return;
    };
}

    // Change sprite when anim counter is 0
    if ( -- (e->anim_counter) == 0 ) {
        ++ e->anim;                               // next animation frame
        // Cycle animation on end of sprites                  
        if ( e->anim->time == 0 ) {               // if last frame (time == 0)
            e->anim = e->anim->val.next;          // next frame = 1st frame
        }
        // Load next sprite from animation
        e->sprite       = e->anim->val.sprite;         
        e->anim_counter = e->anim->time;          // reset anim counter
    }
}



//==============================================================================
//==============================================================================
// PUBLIC FUNCTIONS
//==============================================================================
//==============================================================================

////////////////////////////////////////////////////////////////////////////////
// UPDATE
//      Updates the animations system
//
// Control inversion:
// The system call the entity manager that loops through all the entities
// calling the animations update for one entity.
// (we provide a pointer to the function to update the animations of one entity)
//
// The system just moves the entities that can be moved (signature movable bit = 1)
// Matching the signature we avoid calling the function for entities that can't be animated.
void sys_animation_update() {
    man_entity_forall_matching( sys_animation_update_one_entity, e_cmp_animated );
}