//-----------------------------LICENSE NOTICE------------------------------------
//
////////////////////////////////////////////////////////////////////////////////
///////////////////////////  SHOOT AND RUN /////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
//
//  Code & Graphics Copyright (C) 2020 Rafa Gutierrez (rafagutierrez@qq.com)
//
//  This file is part of Shoot and run: an Amstrad CPC Game made with CPCTelera
//  for CPCRetroDev 2020
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.


#include <cpctelera.h>
#include "palette_scr.h"
#include <string.h>

#define SCREEN_TOP_LEFT       cpctm_screenPtr (CPCT_VMEM_START, 0, 0)
#define SCREEN_BOTTOM_CENTER  cpctm_screenPtr (CPCT_VMEM_START, 26, 180)

#define GAME_LOAD_ADDRESS     (void *)0x4500
#define GAME_RUN_ADDRESS      (void *)0x843A       // Check binaryAddresses.log in game/obj
#define GAME_BIN_SIZE                  28396       // Size in bytes of the file ls -l ../game/obj/*.bin

// NOTE: LOADER CAN'T GET HIGHER THAN 0X4500.
//       UPDATE BIN_SIZE after modify the game

//==============================================================================
// PRIVATE FUNCTIONS
//==============================================================================
void pause(u8 seconds) {

    for (u8 i=0; i<seconds; i++) {
      for (u8 j=0; j<50; j++) {
         cpct_waitVSYNC();
         cpct_waitHalts(2);
       }
   }

}

void write_txt_line(u8* pvmem, const u8* text) {
   u8 len=strlen(text); 

   for (u8 i=0; i<len; i++) {
      cpct_drawCharM2 (pvmem, 143);
      cpct_waitHalts(15);
      cpct_drawCharM2 (pvmem, text[i]);
      pvmem++;
   }

}


////////////////////////////////////////////////////////////////////////////////
// INIT THE INTRO
//    
////////////////////////////////////////////////////////////////////////////////
void intro_init() {

    cpct_setVideoMode(2);
    cpct_setBorder(HW_BLACK);    
    cpct_setPALColour (0, HW_BLACK);
    cpct_setPALColour (1, HW_BRIGHT_CYAN);

}


////////////////////////////////////////////////////////////////////////////////
// SHOW THE INTRO
//    
////////////////////////////////////////////////////////////////////////////////
void intro_show() {
   const u8 *text1   = "GREETINGS PROFESSOR FALKEN.";
   const u8 *text2   = "SHALL WE PLAY A GAME?";
   const u8 *text3   = "LET'S TRY A NEW GAME FROM CPCRETRODEV2020";
   const u8 *text4   = "LOADING THE GAME...";

   u8* pvmem = SCREEN_TOP_LEFT;  

   pause(2);
   
   cpct_drawCharM2 (SCREEN_TOP_LEFT, 143);
   pause(3);

   write_txt_line(pvmem, text1); pvmem += 0xA0;
   pause(2);
   
   write_txt_line(pvmem, text2); pvmem += 0xA0;
   pause(3);

   while (!cpct_isAnyKeyPressed ()) {
      cpct_scanKeyboard();
   }

   write_txt_line(pvmem, text3); pvmem += 0xA0;
   pause(2);

   write_txt_line(pvmem, text4); pvmem += 0xA0;
   pause(2);   

}


void main(void) {
   void (*gameMain)(void);

   cpct_disableFirmware();

   intro_init();
   intro_show();

   cpct_memset ((void*)0xC000, 0, 0x4000);            // Clean the screen

   // Get ready to load the screen
   cpct_setVideoMode(1);   
   cpct_setPalette(palette_scr, 4);

   // Loading screen
   cpct_miniload((void*)0xC000, 0x4000); 

   // Load game and call gameMain
   cpct_miniload(GAME_LOAD_ADDRESS, GAME_BIN_SIZE);     
   cpct_memset ((void*)0xC000, 0, 0x4000);            // Clean the screen  

   gameMain = GAME_RUN_ADDRESS;
   gameMain();       

   // Loop forever
   //while (1);
}
